@@ -11,12 +11,16 @@
 #include <Eina.h>
 #include <Eo.h>
 
+#ifdef EFL_BETA_API_SUPPORT
+#include "Efl_Net.h"
+#endif
+
 #ifdef EAPI
 # undef EAPI
 #endif
 
 #ifdef _WIN32
-# ifdef EFL_ECORE_CON_BUILD
+# ifdef EFL_BUILD
 #  ifdef DLL_EXPORT
 #   define EAPI __declspec(dllexport)
 #  else
@@ -299,10 +303,6 @@ typedef void (*Ecore_Con_Dns_Cb)(const char *canonname,
 
 /** @} */
 
-#ifdef EFL_BETA_API_SUPPORT
-#include "Ecore_Con_Eo.h"
-#endif
-
 /**
  * @struct _Ecore_Con_Server
  * Used to provide legacy ABI/ABI compatibility with non-Eo applications.
@@ -857,10 +857,10 @@ EAPI const char       *ecore_con_ssl_server_verify_name_get(Ecore_Con_Server *sv
  * @param ssl_type The SSL connection type (ONLY).
  * @return @c EINA_FALSE if the connection cannot be upgraded, otherwise @c EINA_TRUE.
  * @note This function is NEVER to be used on a server object created with ecore_con_server_add.
- * @warning Setting a wrong value for @p compl_type WILL mess up your program.
+ * @warning Setting a wrong value for @p ssl_type WILL mess up your program.
  * @since 1.1
  */
-EAPI Eina_Bool         ecore_con_ssl_server_upgrade(Ecore_Con_Server *svr, Ecore_Con_Type compl_type);
+EAPI Eina_Bool         ecore_con_ssl_server_upgrade(Ecore_Con_Server *svr, Ecore_Con_Type ssl_type);
 
 /**
  * @brief Upgrades a connection to a specified level of encryption.
@@ -871,10 +871,10 @@ EAPI Eina_Bool         ecore_con_ssl_server_upgrade(Ecore_Con_Server *svr, Ecore
  * @param cl The client object.
  * @param ssl_type The SSL connection type (ONLY).
  * @return @c EINA_FALSE if the connection cannot be upgraded, otherwise @c EINA_TRUE.
- * @warning Setting a wrong value for @p compl_type WILL mess up your program.
+ * @warning Setting a wrong value for @p ssl_type WILL mess up your program.
  * @since 1.1
  */
-EAPI Eina_Bool         ecore_con_ssl_client_upgrade(Ecore_Con_Client *cl, Ecore_Con_Type compl_type);
+EAPI Eina_Bool         ecore_con_ssl_client_upgrade(Ecore_Con_Client *cl, Ecore_Con_Type ssl_type);
 
 /**
  * @}
@@ -1132,7 +1132,7 @@ EAPI void             ecore_con_socks_apply_always(Ecore_Con_Socks *ecs);
  * @endhtmlonly
  *
  * @image rtf ecore_con-client-server.png
- * @image latex ecore_con-client-server.eps width=\textwidth
+ * @image latex ecore_con-client-server.eps width=\\textwidth
  *
  * Please notice the important difference between these two codes: the first is
  * used for writing a @b server, while the second should be used for writing a
@@ -1778,7 +1778,7 @@ typedef enum _Ecore_Con_Url_Http_Version
  * @see ecore_con_url_pipeline_get()
  */
 EAPI Eina_Bool         ecore_con_url_http_version_set(Ecore_Con_Url *url_con, Ecore_Con_Url_Http_Version version);
-   
+
 /**
  * @brief Initializes the Ecore_Con_Url library.
  * @return Number of times the library has been initialised without being
@@ -2366,6 +2366,23 @@ EAPI void ecore_con_url_timeout_set(Ecore_Con_Url *url_con, double timeout);
  * @since 1.2
  */
 EAPI int ecore_con_url_status_code_get(Ecore_Con_Url *url_con);
+
+/**
+ * @brief Sets a maximum upload speed.
+ *
+ * @param url_con Connection object
+ * @param max_speed Maximum upload speed, in bytes per second
+ */
+EAPI void ecore_con_url_limit_upload_speed(Ecore_Con_Url *url_obj, off_t max_speed);
+
+/**
+ * @brief Sets a maximum download speed.
+ *
+ * @param url_con Connection object
+ * @param max_speed Maximum download speed, in bytes per second
+ */
+EAPI void ecore_con_url_limit_download_speed(Ecore_Con_Url *url_obj, off_t max_speed);
+
 /**
  * @}
  */
