@@ -15,7 +15,7 @@ typedef Eo Efl_Net_Dialer_Websocket;
  *
  * @since 1.19
  *
- * @ingroup Efl_Net_Dialer_Websocket
+ * @ingroup Efl_Net
  */
 typedef enum
 {
@@ -45,95 +45,119 @@ typedef enum
  *
  * @since 1.19
  *
- * @ingroup Efl_Net_Dialer_Websocket
+ * @ingroup Efl_Net
  */
 typedef enum
 {
-  EFL_NET_DIALER_WEBSOCKET_CLOSE_REASON_NORMAL = 1000 /* 0 */, /**< Indicates a normal closure, meaning
-                                                                * that the purpose for which the
-                                                                * connection was established has been
-                                                                * fulfilled. */
-  EFL_NET_DIALER_WEBSOCKET_CLOSE_REASON_GOING_AWAY = 1001 /* 0 */, /**< Indicates that an endpoint is
-                                                                    * "going away", such as a server going
-                                                                    * down or a browser having navigated
-                                                                    * away from a page. */
-  EFL_NET_DIALER_WEBSOCKET_CLOSE_REASON_PROTOCOL_ERROR = 1002 /* 0 */, /**< Indicates that an endpoint is
-                                                                        * terminating the connection due to a
-                                                                        * protocol error. */
-  EFL_NET_DIALER_WEBSOCKET_CLOSE_REASON_NO_REASON = 1005 /* 0 */, /**< Reserved value and MUST NOT be set
-                                                                   * as a status code in a Close control
-                                                                   * frame by an endpoint. It is
-                                                                   * designated for use in applications
-                                                                   * expecting a status code to indicate
-                                                                   * that no status code was actually
-                                                                   * present. */
-  EFL_NET_DIALER_WEBSOCKET_CLOSE_REASON_ABRUPTLY = 1006 /* 0 */, /**< Reserved value and MUST NOT be set
-                                                                  * as a status code in a Close control
-                                                                  * frame by an endpoint.  It is
-                                                                  * designated for use in applications
-                                                                  * expecting a status code to indicate
-                                                                  * that the connection was closed
-                                                                  * abnormally, e.g., without sending or
-                                                                  * receiving a Close control frame. */
-  EFL_NET_DIALER_WEBSOCKET_CLOSE_REASON_UNEXPECTED_DATA = 1003 /* 0 */, /**< Indicates that an endpoint is
-                                                                         * terminating the connection because
-                                                                         * it has received a type of data it
-                                                                         * cannot accept (e.g., an endpoint
-                                                                         * that understands only text data MAY
-                                                                         * send this if it receives a binary
-                                                                         * message). */
-  EFL_NET_DIALER_WEBSOCKET_CLOSE_REASON_INCONSISTENT_DATA = 1007 /* 0 */, /**< Indicates that an endpoint is
-                                                                           * terminating the connection because
-                                                                           * it has received data within a
-                                                                           * message that was not consistent with
-                                                                           * the type of the message (e.g.,
-                                                                           * non-UTF-8 data within a text
-                                                                           * message). */
-  EFL_NET_DIALER_WEBSOCKET_CLOSE_REASON_POLICY_VIOLATION = 1008 /* 0 */, /**< Indicates that an endpoint is
-                                                                          * terminating the connection because
-                                                                          * it has received a message that
-                                                                          * violates its policy.  This is a
-                                                                          * generic status code that can be
-                                                                          * returned when there is no other more
-                                                                          * suitable status code (e.g., 1003 or
-                                                                          * 1009) or if there is a need to hide
-                                                                          * specific details about the policy.
-                                                                          */
-  EFL_NET_DIALER_WEBSOCKET_CLOSE_REASON_TOO_BIG = 1009 /* 0 */, /**< Indicates that an endpoint is
+  EFL_NET_DIALER_WEBSOCKET_CLOSE_REASON_NORMAL = 1000, /**< Indicates a normal
+                                                        * closure, meaning that
+                                                        * the purpose for which
+                                                        * the connection was
+                                                        * established has been
+                                                        * fulfilled. */
+  EFL_NET_DIALER_WEBSOCKET_CLOSE_REASON_GOING_AWAY = 1001, /**< Indicates that
+                                                            * an endpoint is
+                                                            * "going away",
+                                                            * such as a server
+                                                            * going down or a
+                                                            * browser having
+                                                            * navigated away
+                                                            * from a page. */
+  EFL_NET_DIALER_WEBSOCKET_CLOSE_REASON_PROTOCOL_ERROR = 1002, /**< Indicates that an endpoint is
+                                                                * terminating the connection due to a
+                                                                * protocol error. */
+  EFL_NET_DIALER_WEBSOCKET_CLOSE_REASON_NO_REASON = 1005, /**< Reserved value
+                                                           * and MUST NOT be
+                                                           * set as a status
+                                                           * code in a Close
+                                                           * control frame by
+                                                           * an endpoint. It is
+                                                           * designated for use
+                                                           * in applications
+                                                           * expecting a status
+                                                           * code to indicate
+                                                           * that no status
+                                                           * code was actually
+                                                           * present. */
+  EFL_NET_DIALER_WEBSOCKET_CLOSE_REASON_ABRUPTLY = 1006, /**< Reserved value and
+                                                          * MUST NOT be set as
+                                                          * a status code in a
+                                                          * Close control frame
+                                                          * by an endpoint.  It
+                                                          * is designated for
+                                                          * use in applications
+                                                          * expecting a status
+                                                          * code to indicate
+                                                          * that the connection
+                                                          * was closed
+                                                          * abnormally, e.g.,
+                                                          * without sending or
+                                                          * receiving a Close
+                                                          * control frame. */
+  EFL_NET_DIALER_WEBSOCKET_CLOSE_REASON_UNEXPECTED_DATA = 1003, /**< Indicates that an endpoint is
                                                                  * terminating the connection because
-                                                                 * it has received a message that is
-                                                                 * too big for it to process. */
-  EFL_NET_DIALER_WEBSOCKET_CLOSE_REASON_MISSING_EXTENSION = 1010 /* 0 */, /**< Indicates that an endpoint (client)
-                                                                           * is terminating the connection
-                                                                           * because it has expected the server
-                                                                           * to negotiate one or more extension,
-                                                                           * but the server didn't return them in
-                                                                           * the response message of the
-                                                                           * WebSocket handshake.  The list of
-                                                                           * extensions that are needed SHOULD
-                                                                           * appear in the reason part of the
-                                                                           * Close frame.  Note that this status
-                                                                           * code is not used by the server,
-                                                                           * because it can fail the WebSocket
-                                                                           * handshake instead. */
-  EFL_NET_DIALER_WEBSOCKET_CLOSE_REASON_SERVER_ERROR = 1011 /* 0 */, /**< Indicates that a server is
-                                                                      * terminating the connection because
-                                                                      * it encountered an unexpected
-                                                                      * condition that prevented it from
-                                                                      * fulfilling the request. */
-  EFL_NET_DIALER_WEBSOCKET_CLOSE_REASON_IANA_REGISTRY_START = 3000 /* 0 */, /**< IANA registry starts at 3000 */
-  EFL_NET_DIALER_WEBSOCKET_CLOSE_REASON_IANA_REGISTRY_END = 3999 /* 0 */, /**< IANA registry ends at 3999 */
-  EFL_NET_DIALER_WEBSOCKET_CLOSE_REASON_PRIVATE_START = 4000 /* 0 */, /**< Applications can use range
-                                                                       * 4000-4999 */
-  EFL_NET_DIALER_WEBSOCKET_CLOSE_REASON_PRIVATE_END = 4999 /* 0 */ /**< Applications can use range
-                                                                    * 4000-4999 */
+                                                                 * it has received a type of data it
+                                                                 * cannot accept (e.g., an endpoint
+                                                                 * that understands only text data MAY
+                                                                 * send this if it receives a binary
+                                                                 * message). */
+  EFL_NET_DIALER_WEBSOCKET_CLOSE_REASON_INCONSISTENT_DATA = 1007, /**< Indicates that an endpoint is
+                                                                   * terminating the connection because
+                                                                   * it has received data within a
+                                                                   * message that was not consistent with
+                                                                   * the type of the message (e.g.,
+                                                                   * non-UTF-8 data within a text
+                                                                   * message). */
+  EFL_NET_DIALER_WEBSOCKET_CLOSE_REASON_POLICY_VIOLATION = 1008, /**< Indicates that an endpoint is
+                                                                  * terminating the connection because
+                                                                  * it has received a message that
+                                                                  * violates its policy.  This is a
+                                                                  * generic status code that can be
+                                                                  * returned when there is no other more
+                                                                  * suitable status code (e.g., 1003 or
+                                                                  * 1009) or if there is a need to hide
+                                                                  * specific details about the policy.
+                                                                  */
+  EFL_NET_DIALER_WEBSOCKET_CLOSE_REASON_TOO_BIG = 1009, /**< Indicates that an
+                                                         * endpoint is
+                                                         * terminating the
+                                                         * connection because
+                                                         * it has received a
+                                                         * message that is too
+                                                         * big for it to
+                                                         * process. */
+  EFL_NET_DIALER_WEBSOCKET_CLOSE_REASON_MISSING_EXTENSION = 1010, /**< Indicates that an endpoint (client)
+                                                                   * is terminating the connection
+                                                                   * because it has expected the server
+                                                                   * to negotiate one or more extension,
+                                                                   * but the server didn't return them in
+                                                                   * the response message of the
+                                                                   * WebSocket handshake.  The list of
+                                                                   * extensions that are needed SHOULD
+                                                                   * appear in the reason part of the
+                                                                   * Close frame.  Note that this status
+                                                                   * code is not used by the server,
+                                                                   * because it can fail the WebSocket
+                                                                   * handshake instead. */
+  EFL_NET_DIALER_WEBSOCKET_CLOSE_REASON_SERVER_ERROR = 1011, /**< Indicates that a server is
+                                                              * terminating the connection because
+                                                              * it encountered an unexpected
+                                                              * condition that prevented it from
+                                                              * fulfilling the request. */
+  EFL_NET_DIALER_WEBSOCKET_CLOSE_REASON_IANA_REGISTRY_START = 3000, /**< IANA registry starts at 3000 */
+  EFL_NET_DIALER_WEBSOCKET_CLOSE_REASON_IANA_REGISTRY_END = 3999, /**< IANA registry ends at 3999 */
+  EFL_NET_DIALER_WEBSOCKET_CLOSE_REASON_PRIVATE_START = 4000, /**< Applications can use range
+                                                               * 4000-4999 */
+  EFL_NET_DIALER_WEBSOCKET_CLOSE_REASON_PRIVATE_END = 4999 /**< Applications can
+                                                            * use range
+                                                            * 4000-4999 */
 } Efl_Net_Dialer_Websocket_Close_Reason;
 
 /** Close reason event payload.
  *
  * @since 1.19
  *
- * @ingroup Efl_Net_Dialer_Websocket
+ * @ingroup Efl_Net
  */
 typedef struct _Efl_Net_Dialer_Websocket_Closed_Reason
 {
@@ -150,14 +174,15 @@ typedef struct _Efl_Net_Dialer_Websocket_Closed_Reason
  * message-based protocol over HTTP, this allows it to leverage on
  * authentication, cookies, proxies and SSL/TLS.
  *
- * It's worth to note that although it uses the HTTP dialer, it's not a
- * subclass and thus not all HTTP features are exposed as the WebSocket has
- * strict requirements that must be respected.
+ * Although it uses the HTTP dialer, it's not a subclass and thus not all HTTP
+ * features are exposed as the WebSocket has strict requirements that must be
+ * respected.
  *
  * If the proxy is NULL (default), then the system proxy will be used. On UNIX
  * that's the environment variable @c http_proxy (or '$all_proxy') is used if
- * the given address doesn't match @c no_proxy patterns. To disable proxy use
- * an empty string. If provided proxy must be one of the protocols:
+ * the given address doesn't match @c no_proxy patterns. To disable the proxy
+ * use an empty string. If provided, the proxy must be one of the following
+ * protocols:
  *
  * - http://username:password\@proxyserver:port -
  * http://username\@proxyserver:port - http://proxyserver:port -
@@ -179,8 +204,9 @@ EWAPI const Efl_Class *efl_net_dialer_websocket_class_get(void);
 /**
  * @brief Sends a PING (opcode=0x9) to the server.
  *
- * The server should reply with a PONG, that will be emitted as "pong" event.
+ * The server should reply with a PONG, which will be emitted as "pong" event.
  *
+ * @param[in] obj The object.
  * @param[in] reason Reason
  *
  * @since 1.19
@@ -192,12 +218,12 @@ EOAPI void efl_net_dialer_websocket_ping(Eo *obj, const char *reason);
 /**
  * @brief Sends an UTF-8 TEXT (opcode=0x1) to the server.
  *
- * The text goes in a message will be delivered as a single entity to the
- * remote peer.
+ * The message text will be delivered as a single entity to the remote peer.
  *
- * The text is copied into a local buffer, no references are kept after this
+ * The text is copied into a local buffer. No references are kept after this
  * method returns.
  *
+ * @param[in] obj The object.
  * @param[in] text Text to send
  *
  * @since 1.19
@@ -209,12 +235,13 @@ EOAPI void efl_net_dialer_websocket_text_send(Eo *obj, const char *text);
 /**
  * @brief Sends a binary blob (opcode=0x2) to the server.
  *
- * The slice describing the blob goes in a message will be delivered as a
+ * The slice describing the blob goes in a message which will be delivered as a
  * single entity to the remote peer.
  *
  * The memory is copied into a local buffer, no references are kept after this
  * method returns.
  *
+ * @param[in] obj The object.
  * @param[in] blob Binary blob to send
  *
  * @since 1.19
@@ -227,17 +254,18 @@ EOAPI void efl_net_dialer_websocket_binary_send(Eo *obj, const Eina_Slice blob);
  * @brief Requests (opcode=0x8) the server to terminate the connection.
  *
  * Unlike @ref efl_io_closer_close, this won't abruptly close the connection,
- * rather will queue a message requesting the server to gracefully close it.
+ * rather it'll queue a message requesting the server to gracefully close it.
  *
  * After this method is called you should consider the object in "closing"
- * state, no more messages can be sent (@Efl.Net.Dialer.Websocket.text_send,
+ * state. No more messages can be sent (@Efl.Net.Dialer_Websocket.text_send,
  * @ref efl_net_dialer_websocket_binary_send and
  * @ref efl_net_dialer_websocket_ping will fail).
  *
  * The object will be automatically closed with @ref efl_io_closer_close once
- * the serve replies with his own close message, that will be reported as
+ * the server replies with his own close message, which will be reported as
  * "closed,reason".
  *
+ * @param[in] obj The object.
  * @param[in] reason Reason for closing
  * @param[in] message Additional closing message
  *
@@ -252,6 +280,7 @@ EOAPI void efl_net_dialer_websocket_close_request(Eo *obj, Efl_Net_Dialer_Websoc
  *
  * This should be set before dialing.
  *
+ * @param[in] obj The object.
  * @param[in] protocol WebSocket protocol
  *
  * @since 1.19
@@ -263,6 +292,8 @@ EOAPI void efl_net_dialer_websocket_request_protocol_add(Eo *obj, const char *pr
 /**
  * @brief Returns an iterator to the requested WebSocket protocols
  *
+ * @param[in] obj The object.
+ *
  * @return Iterator to protocols
  *
  * @since 1.19
@@ -283,6 +314,8 @@ EOAPI void efl_net_dialer_websocket_request_protocols_clear(Eo *obj);
  * @brief Returns an iterator to the server-replied (response) WebSocket
  * protocols it supports
  *
+ * @param[in] obj The object.
+ *
  * @return Iterator to server protocols
  *
  * @since 1.19
@@ -311,8 +344,9 @@ EOAPI Eina_Iterator *efl_net_dialer_websocket_response_protocols_get(Eo *obj) EI
  * differs from SOCK_SEQPACKET + read(2)).
  *
  * By default, streaming is disabled
- * (@Efl.Net.Dialer.Websocket.Streaming_Mode.disabled).
+ * (@Efl.Net.Dialer_Websocket_Streaming_Mode.disabled).
  *
+ * @param[in] obj The object.
  * @param[in] streaming_mode Streaming mode
  *
  * @since 1.19
@@ -341,7 +375,9 @@ EOAPI void efl_net_dialer_websocket_streaming_mode_set(Eo *obj, Efl_Net_Dialer_W
  * differs from SOCK_SEQPACKET + read(2)).
  *
  * By default, streaming is disabled
- * (@Efl.Net.Dialer.Websocket.Streaming_Mode.disabled).
+ * (@Efl.Net.Dialer_Websocket_Streaming_Mode.disabled).
+ *
+ * @param[in] obj The object.
  *
  * @return Streaming mode
  *
@@ -356,6 +392,7 @@ EOAPI Efl_Net_Dialer_Websocket_Streaming_Mode efl_net_dialer_websocket_streaming
  *
  * This should be set before dialing.
  *
+ * @param[in] obj The object.
  * @param[in] user_agent User-agent
  *
  * @since 1.19
@@ -369,6 +406,8 @@ EOAPI void efl_net_dialer_websocket_user_agent_set(Eo *obj, const char *user_age
  *
  * This should be set before dialing.
  *
+ * @param[in] obj The object.
+ *
  * @return User-agent
  *
  * @since 1.19
@@ -382,9 +421,10 @@ EOAPI const char *efl_net_dialer_websocket_user_agent_get(const Eo *obj);
  *
  * This should be set before dialing.
  *
+ * @param[in] obj The object.
  * @param[in] username HTTP authentication username
  * @param[in] password HTTP authentication password
- * @param[in] method Authentication method to use, defaults to
+ * @param[in] method The authentication method to use. Defaults to
  * @ref EFL_NET_HTTP_AUTHENTICATION_METHOD_BASIC
  * @param[in] restricted Restrict method
  *
@@ -399,9 +439,10 @@ EOAPI void efl_net_dialer_websocket_authentication_set(Eo *obj, const char *user
  *
  * This should be set before dialing.
  *
+ * @param[in] obj The object.
  * @param[out] username HTTP authentication username
  * @param[out] password HTTP authentication password
- * @param[out] method Authentication method to use, defaults to
+ * @param[out] method The authentication method to use. Defaults to
  * @ref EFL_NET_HTTP_AUTHENTICATION_METHOD_BASIC
  * @param[out] restricted Restrict method
  *
@@ -416,6 +457,7 @@ EOAPI void efl_net_dialer_websocket_authentication_get(const Eo *obj, const char
  *
  * This should be set before dialing.
  *
+ * @param[in] obj The object.
  * @param[in] allow_redirects @c true when following redirects, @c false
  * otherwise
  *
@@ -430,6 +472,8 @@ EOAPI void efl_net_dialer_websocket_allow_redirects_set(Eo *obj, Eina_Bool allow
  *
  * This should be set before dialing.
  *
+ * @param[in] obj The object.
+ *
  * @return @c true when following redirects, @c false otherwise
  *
  * @since 1.19
@@ -451,6 +495,7 @@ EOAPI Eina_Bool efl_net_dialer_websocket_allow_redirects_get(const Eo *obj);
  *
  * This should be called before dialing.
  *
+ * @param[in] obj The object.
  * @param[in] key HTTP request header key
  * @param[in] value HTTP request header value
  *
@@ -467,6 +512,8 @@ EOAPI void efl_net_dialer_websocket_request_header_add(Eo *obj, const char *key,
  *
  * This should be called before dialing.
  *
+ * @param[in] obj The object.
+ *
  * @since 1.19
  *
  * @ingroup Efl_Net_Dialer_Websocket
@@ -476,6 +523,8 @@ EOAPI void efl_net_dialer_websocket_request_headers_clear(Eo *obj);
 /**
  * @brief Returns an iterator to the key-value pairs for request headers
  *
+ * @param[in] obj The object.
+ *
  * @return Iterator to key value pairs
  *
  * @since 1.19
@@ -487,24 +536,25 @@ EOAPI Eina_Iterator *efl_net_dialer_websocket_request_headers_get(Eo *obj) EINA_
 /**
  * @brief This property sets the filename where to read and write cookies.
  *
- * By setting a file to load and persist cookies to, the internal cookie system
- * will be activated, automatically handling HTTP headers such as 'Set-cookie:'
- * and sending the appropriate cookies for a server.
+ * By setting a file to load and store cookies, the internal cookie system will
+ * be activated, automatically handling HTTP headers such as 'Set-cookie:' and
+ * sending the appropriate cookies for a server.
  *
  * If a new, empty session is to be used, start with an empty or non-existent
- * file such as created with mkstemp() or tmpfile(). An alternative is to use
- * an empty string ("") to keep it in memory.
+ * file such as one created with mkstemp() or tmpfile(). Alternatively use an
+ * empty string ("") to keep it in memory.
  *
- * If it is desired to start from a pre-existent cookie jar but do not want to
- * modify that, first copy that file and then pass the new, temporary file.
+ * If you want to start from a pre-existent cookie jar but do not want to
+ * modify it, first copy that file and then pass the new, temporary file.
  *
- * Likewise, if it's desired to fill some cookies to the system, create a
- * cookie jar and pass its path to this property.
+ * Likewise, if you want to store some cookies in the system, create a cookie
+ * jar and pass its path to this property.
  *
  * @note that whenever this property is set, even if to the same value, it will
  * flush all cookies to the previously set file, then erase all known cookies,
  * then use the new file (if any).
  *
+ * @param[in] obj The object.
  * @param[in] path Path to cookie jar
  *
  * @since 1.19
@@ -516,24 +566,26 @@ EOAPI void efl_net_dialer_websocket_cookie_jar_set(Eo *obj, const char *path);
 /**
  * @brief This property sets the filename where to read and write cookies.
  *
- * By setting a file to load and persist cookies to, the internal cookie system
- * will be activated, automatically handling HTTP headers such as 'Set-cookie:'
- * and sending the appropriate cookies for a server.
+ * By setting a file to load and store cookies, the internal cookie system will
+ * be activated, automatically handling HTTP headers such as 'Set-cookie:' and
+ * sending the appropriate cookies for a server.
  *
  * If a new, empty session is to be used, start with an empty or non-existent
- * file such as created with mkstemp() or tmpfile(). An alternative is to use
- * an empty string ("") to keep it in memory.
+ * file such as one created with mkstemp() or tmpfile(). Alternatively use an
+ * empty string ("") to keep it in memory.
  *
- * If it is desired to start from a pre-existent cookie jar but do not want to
- * modify that, first copy that file and then pass the new, temporary file.
+ * If you want to start from a pre-existent cookie jar but do not want to
+ * modify it, first copy that file and then pass the new, temporary file.
  *
- * Likewise, if it's desired to fill some cookies to the system, create a
- * cookie jar and pass its path to this property.
+ * Likewise, if you want to store some cookies in the system, create a cookie
+ * jar and pass its path to this property.
  *
  * @note that whenever this property is set, even if to the same value, it will
  * flush all cookies to the previously set file, then erase all known cookies,
  * then use the new file (if any).
  *
+ * @param[in] obj The object.
+ *
  * @return Path to cookie jar
  *
  * @since 1.19
