@@ -13,9 +13,13 @@ typedef Eo Efl_Gfx_Fill;
 
 
 #endif
+/** Efl graphics fill interface
+ *
+ * @ingroup Efl_Gfx_Fill
+ */
 #define EFL_GFX_FILL_INTERFACE efl_gfx_fill_interface_get()
 
-EWAPI const Eo_Class *efl_gfx_fill_interface_get(void);
+EWAPI const Efl_Class *efl_gfx_fill_interface_get(void);
 
 /**
  * @brief Binds the object's @ref efl_gfx_fill_get property to its actual
@@ -31,6 +35,30 @@ EWAPI const Eo_Class *efl_gfx_fill_interface_get(void);
  * This flag is @c true by default (used to be @c false with the old APIs, and
  * was known as "filled").
  *
+ * @param[in] obj The object.
+ * @param[in] filled @c true to make the fill property follow object size or
+ * @c false otherwise.
+ *
+ * @ingroup Efl_Gfx_Fill
+ */
+EOAPI void efl_gfx_fill_auto_set(Eo *obj, Eina_Bool filled);
+
+/**
+ * @brief Binds the object's @ref efl_gfx_fill_get property to its actual
+ * geometry.
+ *
+ * If @c true, then every time the object is resized, it will automatically
+ * trigger a call to @ref efl_gfx_fill_set with the new size (and 0, 0 as
+ * source image's origin), so the image will cover the whole object's area.
+ *
+ * This property takes precedence over @ref efl_gfx_fill_get. If set to
+ * @c false, then @ref efl_gfx_fill_get should be set.
+ *
+ * This flag is @c true by default (used to be @c false with the old APIs, and
+ * was known as "filled").
+ *
+ * @param[in] obj The object.
+ *
  * @return @c true to make the fill property follow object size or @c false
  * otherwise.
  *
@@ -39,25 +67,23 @@ EWAPI const Eo_Class *efl_gfx_fill_interface_get(void);
 EOAPI Eina_Bool efl_gfx_fill_auto_get(const Eo *obj);
 
 /**
- * @brief Binds the object's @ref efl_gfx_fill_get property to its actual
- * geometry.
+ * @brief Specifies how to tile an image to fill its rectangle geometry.
  *
- * If @c true, then every time the object is resized, it will automatically
- * trigger a call to @ref efl_gfx_fill_set with the new size (and 0, 0 as
- * source image's origin), so the image will cover the whole object's area.
+ * Note that if @c w or @c h are smaller than the dimensions of the object, the
+ * displayed image will be tiled around the object's area. To have only one
+ * copy of the bound image drawn, @c x and @c y must be 0 and @c w and @c h
+ * need to be the exact width and height of the image object itself,
+ * respectively.
  *
- * This property takes precedence over @ref efl_gfx_fill_get. If set to
- * @c false, then @ref efl_gfx_fill_get should be set.
+ * Setting this property will reset the @ref efl_gfx_fill_auto_get to @c false.
  *
- * This flag is @c true by default (used to be @c false with the old APIs, and
- * was known as "filled").
- *
- * @param[in] filled @c true to make the fill property follow object size or
- * @c false otherwise.
+ * @param[in] obj The object.
+ * @param[in] fill The top-left corner to start drawing from as well as the
+ * size at which the bound image will be displayed.
  *
  * @ingroup Efl_Gfx_Fill
  */
-EOAPI void efl_gfx_fill_auto_set(Eo *obj, Eina_Bool filled);
+EOAPI void efl_gfx_fill_set(Eo *obj, Eina_Rect fill);
 
 /**
  * @brief Specifies how to tile an image to fill its rectangle geometry.
@@ -70,38 +96,13 @@ EOAPI void efl_gfx_fill_auto_set(Eo *obj, Eina_Bool filled);
  *
  * Setting this property will reset the @ref efl_gfx_fill_auto_get to @c false.
  *
- * @param[out] x The x coordinate (from the top left corner of the bound image)
- * to start drawing from.
- * @param[out] y The y coordinate (from the top left corner of the bound image)
- * to start drawing from.
- * @param[out] w The width the bound image will be displayed at.
- * @param[out] h The height the bound image will be displayed at.
+ * @param[in] obj The object.
+ *
+ * @return The top-left corner to start drawing from as well as the size at
+ * which the bound image will be displayed.
  *
  * @ingroup Efl_Gfx_Fill
  */
-EOAPI void efl_gfx_fill_get(const Eo *obj, int *x, int *y, int *w, int *h);
-
-/**
- * @brief Specifies how to tile an image to fill its rectangle geometry.
- *
- * Note that if @c w or @c h are smaller than the dimensions of the object, the
- * displayed image will be tiled around the object's area. To have only one
- * copy of the bound image drawn, @c x and @c y must be 0 and @c w and @c h
- * need to be the exact width and height of the image object itself,
- * respectively.
- *
- * Setting this property will reset the @ref efl_gfx_fill_auto_get to @c false.
- *
- * @param[in] x The x coordinate (from the top left corner of the bound image)
- * to start drawing from.
- * @param[in] y The y coordinate (from the top left corner of the bound image)
- * to start drawing from.
- * @param[in] w The width the bound image will be displayed at.
- * @param[in] h The height the bound image will be displayed at.
- *
- * @ingroup Efl_Gfx_Fill
- */
-EOAPI void efl_gfx_fill_set(Eo *obj, int x, int y, int w, int h);
-
+EOAPI Eina_Rect efl_gfx_fill_get(const Eo *obj);
 
 #endif
