@@ -13,48 +13,56 @@ typedef Eo Efl_Gfx_Gradient;
 
 
 #endif
-#define EFL_GFX_GRADIENT_INTERFACE efl_gfx_gradient_interface_get()
-
-EWAPI const Eo_Class *efl_gfx_gradient_interface_get(void);
-
-/**
- * @brief Get the list of color stops.
- *
- * @param[out] colors color stops list
- * @param[out] length length of the list
+/** Efl graphics gradient interface
  *
  * @ingroup Efl_Gfx_Gradient
  */
-EOAPI void efl_gfx_gradient_stop_get(const Eo *obj, const Efl_Gfx_Gradient_Stop **colors, unsigned int *length);
+#define EFL_GFX_GRADIENT_INTERFACE efl_gfx_gradient_interface_get()
+
+EWAPI const Efl_Class *efl_gfx_gradient_interface_get(void);
 
 /**
  * @brief Set the list of color stops for the gradient
  *
- * @param[in] colors color stops list
- * @param[in] length length of the list
+ * @param[in] obj The object.
+ * @param[in] colors Color stops list
+ * @param[in] length Length of the list
  *
  * @ingroup Efl_Gfx_Gradient
  */
 EOAPI void efl_gfx_gradient_stop_set(Eo *obj, const Efl_Gfx_Gradient_Stop *colors, unsigned int length);
 
 /**
- * @brief Returns the spread method use by this gradient. The default is
- * EFL_GFX_GRADIENT_SPREAD_PAD.
+ * @brief Get the list of color stops.
  *
- * @return spread type to be used
+ * @param[in] obj The object.
+ * @param[out] colors Color stops list
+ * @param[out] length Length of the list
  *
  * @ingroup Efl_Gfx_Gradient
  */
-EOAPI Efl_Gfx_Gradient_Spread efl_gfx_gradient_spread_get(const Eo *obj);
+EOAPI void efl_gfx_gradient_stop_get(const Eo *obj, const Efl_Gfx_Gradient_Stop **colors, unsigned int *length);
 
 /**
  * @brief Specifies the spread method that should be used for this gradient.
  *
- * @param[in] s spread type to be used
+ * @param[in] obj The object.
+ * @param[in] s Spread type to be used
  *
  * @ingroup Efl_Gfx_Gradient
  */
 EOAPI void efl_gfx_gradient_spread_set(Eo *obj, Efl_Gfx_Gradient_Spread s);
 
+/**
+ * @brief Returns the spread method use by this gradient. The default is
+ * EFL_GFX_GRADIENT_SPREAD_PAD.
+ *
+ * @param[in] obj The object.
+ *
+ * @return Spread type to be used
+ *
+ * @ingroup Efl_Gfx_Gradient
+ */
+EOAPI Efl_Gfx_Gradient_Spread efl_gfx_gradient_spread_get(const Eo *obj);
 
 #endif
