@@ -30,6 +30,7 @@ EWAPI const Efl_Class *efl_ui_check_class_get(void);
 /**
  * @brief The on/off state of the check object.
  *
+ * @param[in] obj The object.
  * @param[in] value @c true if the check object is selected, @c false otherwise
  *
  * @ingroup Efl_Ui_Check
@@ -39,19 +40,12 @@ EOAPI void efl_ui_check_selected_set(Eo *obj, Eina_Bool value);
 /**
  * @brief The on/off state of the check object.
  *
+ * @param[in] obj The object.
+ *
  * @return @c true if the check object is selected, @c false otherwise
  *
  * @ingroup Efl_Ui_Check
  */
 EOAPI Eina_Bool efl_ui_check_selected_get(const Eo *obj);
 
-EWAPI extern const Efl_Event_Description _EFL_UI_CHECK_EVENT_CHANGED;
-
-/** This is called whenever the user changes the state of the check objects
- * (event_info is always NULL).
- *
- * @ingroup Efl_Ui_Check
- */
-#define EFL_UI_CHECK_EVENT_CHANGED (&(_EFL_UI_CHECK_EVENT_CHANGED))
-
 #endif
