@@ -11,54 +11,6 @@ typedef Eo Elm_Genlist_Item;
 #ifndef _ELM_GENLIST_ITEM_EO_TYPES
 #define _ELM_GENLIST_ITEM_EO_TYPES
 
-/** Defines if the item is of any special type (has subitems or it's the index
- * of a group), or is just a simple item.
- *
- * @ingroup Elm_Genlist_Item
- */
-typedef enum
-{
-  ELM_GENLIST_ITEM_NONE = 0, /**< Simple item. */
-  ELM_GENLIST_ITEM_TREE = 1 /* 0 >> 0 */, /**< This may be expanded and have
-                                           * child items. */
-  ELM_GENLIST_ITEM_GROUP = 2 /* 0 >> 0 */, /**< An index item of a group of
-                                            * items. this item can have child
-                                            * items. */
-  ELM_GENLIST_ITEM_MAX = 4 /* 0 >> 0 */ /**< Sentinel value to indicate last
-                                         * enum field during iteration */
-} Elm_Genlist_Item_Type;
-
-/** Defines the type of the item part Used while updating item's parts It can
- * be used at updating multi fields.
- *
- * @ingroup Elm_Genlist_Item
- */
-typedef enum
-{
-  ELM_GENLIST_ITEM_FIELD_ALL = 0, /**< Type all */
-  ELM_GENLIST_ITEM_FIELD_TEXT = 1 /* 0 >> 0 */, /**< Type text */
-  ELM_GENLIST_ITEM_FIELD_CONTENT = 2 /* 0 >> 0 */, /**< Type content */
-  ELM_GENLIST_ITEM_FIELD_STATE = 4 /* 0 >> 0 */ /**< Type state */
-} Elm_Genlist_Item_Field_Type;
-
-/** Defines where to position the item in the genlist.
- *
- * @ingroup Elm_Genlist_Item
- */
-typedef enum
-{
-  ELM_GENLIST_ITEM_SCROLLTO_NONE = 0, /**< Nothing will happen, Don't use this
-                                       * value. */
-  ELM_GENLIST_ITEM_SCROLLTO_IN = 1 /* 0 >> 0 */, /**< To the nearest viewport.
-                                                  */
-  ELM_GENLIST_ITEM_SCROLLTO_TOP = 2 /* 0 >> 0 */, /**< To the top of viewport.
-                                                   */
-  ELM_GENLIST_ITEM_SCROLLTO_MIDDLE = 4 /* 0 >> 0 */, /**< To the middle of
-                                                      * viewport. */
-  ELM_GENLIST_ITEM_SCROLLTO_BOTTOM = 8 /* 0 >> 0 */ /**< To the bottom of
-                                                     * viewport. */
-} Elm_Genlist_Item_Scrollto_Type;
-
 
 #endif
 
@@ -71,6 +23,14 @@ typedef enum
  * If filter is set on genlist, this returns the filtered item placed before
  * @c item in the list.
  *
+ * Note that parent / child relationship is not taken into account, the
+ * previous visual item is always returned, could it be a parent, a child or a
+ * group item.
+ *
+ * NULL is returned if called on the first item.
+ *
+ * @param[in] obj The object.
+ *
  * @return The item before @c item, or @c null if there's none (and on errors).
  *
  * @ingroup Elm_Genlist_Item
@@ -86,9 +46,13 @@ EAPI Elm_Widget_Item *elm_genlist_item_prev_get(const Elm_Genlist_Item *obj);
  * If filter is set on genlist, this returns the filtered item placed after
  * @c item in the list.
  *
- * Also the next item means item in the same tree level. If a item has
- * subitems, and it have expand all subitems will be ignore, and will get the
- * next item in the same level.
+ * Note that parent / child relationship is not taken into account, the next
+ * visual item is always returned, could it be a parent, a child or a group
+ * item.
+ *
+ * NULL is returned if called on the last item.
+ *
+ * @param[in] obj The object.
  *
  * @return The item after @c item, or @c null if there's none (and on errors).
  *
@@ -102,6 +66,8 @@ EAPI Elm_Widget_Item *elm_genlist_item_next_get(const Elm_Genlist_Item *obj);
  * This returns the item that was specified as parent of the item @c it on @ref
  * elm_genlist_item_append and insertion related functions.
  *
+ * @param[in] obj The object.
+ *
  * @return The parent of the item or @c null if it has no parent.
  *
  * @ingroup Elm_Genlist_Item
@@ -109,11 +75,13 @@ EAPI Elm_Widget_Item *elm_genlist_item_next_get(const Elm_Genlist_Item *obj);
 EAPI Elm_Widget_Item *elm_genlist_item_parent_get(const Elm_Genlist_Item *obj);
 
 /**
- * @brief et the list of subitems of a given item
+ * @brief Get the list of subitems of a given item
  *
  * This returns the list of subitems that an item possesses. It cannot be
  * changed.
  *
+ * @param[in] obj The object.
+ *
  * @return The list of subitems, @c null on error.
  *
  * @since 1.9
@@ -129,6 +97,7 @@ EAPI const Eina_List *elm_genlist_item_subitems_get(const Elm_Genlist_Item *obj)
  * on the containing genlist and @c selected is @c true, any other previously
  * selected items will get unselected in favor of this new one.
  *
+ * @param[in] obj The object.
  * @param[in] selected The selected state ($true selected, @c false not
  * selected).
  *
@@ -139,6 +108,8 @@ EAPI void elm_genlist_item_selected_set(Elm_Genlist_Item *obj, Eina_Bool selecte
 /**
  * @brief Get whether a given genlist item is selected or not.
  *
+ * @param[in] obj The object.
+ *
  * @return The selected state ($true selected, @c false not selected).
  *
  * @ingroup Elm_Genlist_Item
@@ -159,6 +130,7 @@ EAPI Eina_Bool elm_genlist_item_selected_get(const Elm_Genlist_Item *obj);
  * parent). You must manually delete and create them on the callbacks of the
  * "expanded" or "contracted" signals.
  *
+ * @param[in] obj The object.
  * @param[in] expanded The expanded state ($true expanded, @c false not
  * expanded).
  *
@@ -171,6 +143,8 @@ EAPI void elm_genlist_item_expanded_set(Elm_Genlist_Item *obj, Eina_Bool expande
  *
  * This gets the expanded state of an item.
  *
+ * @param[in] obj The object.
+ *
  * @return The expanded state ($true expanded, @c false not expanded).
  *
  * @ingroup Elm_Genlist_Item
@@ -180,6 +154,8 @@ EAPI Eina_Bool elm_genlist_item_expanded_get(const Elm_Genlist_Item *obj);
 /**
  * @brief Get the depth of expanded item.
  *
+ * @param[in] obj The object.
+ *
  * @return The depth of expanded item.
  *
  * @ingroup Elm_Genlist_Item
@@ -192,6 +168,8 @@ EAPI int elm_genlist_item_expanded_depth_get(const Elm_Genlist_Item *obj);
  * This returns the Genlist_Item_Class for the given item. It can be used to
  * examine the function pointers and item_style.
  *
+ * @param[in] obj The object.
+ *
  * @return Genlist Item class for the given item.
  *
  * @ingroup Elm_Genlist_Item
@@ -203,6 +181,8 @@ EAPI const Elm_Genlist_Item_Class *elm_genlist_item_item_class_get(const Elm_Gen
  *
  * The index start from 1.
  *
+ * @param[in] obj The object.
+ *
  * @return The position inside the list of item.
  *
  * @ingroup Elm_Genlist_Item
@@ -214,6 +194,8 @@ EAPI int elm_genlist_item_index_get(const Elm_Genlist_Item *obj);
  *
  * This function just returns the name of the item's decorate mode.
  *
+ * @param[in] obj The object.
+ *
  * @return Name of the item's decorate mode.
  *
  * @ingroup Elm_Genlist_Item
@@ -227,6 +209,7 @@ EAPI const char *elm_genlist_item_decorate_mode_get(const Elm_Genlist_Item *obj)
  * overrides current item object. It can be used for on-the-fly item replace.
  * Flip mode can be used with/without decorate mode.
  *
+ * @param[in] obj The object.
  * @param[in] flip The flip mode.
  *
  * @ingroup Elm_Genlist_Item
@@ -239,6 +222,8 @@ EAPI void elm_genlist_item_flip_set(Elm_Genlist_Item *obj, Eina_Bool flip);
  * This function returns the flip state of a given genlist item. If the
  * parameter is invalid, it returns @c false.
  *
+ * @param[in] obj The object.
+ *
  * @return The flip mode.
  *
  * @ingroup Elm_Genlist_Item
@@ -266,6 +251,7 @@ EAPI Eina_Bool elm_genlist_item_flip_get(const Elm_Genlist_Item *obj);
  * it is enabled, the item can be shrink than predefined finger-size value. And
  * the item will be updated.
  *
+ * @param[in] obj The object.
  * @param[in] mode The selected mode.
  *
  * @ingroup Elm_Genlist_Item
@@ -277,6 +263,8 @@ EAPI void elm_genlist_item_select_mode_set(Elm_Genlist_Item *obj, Elm_Object_Sel
  *
  * It's ELM_OBJECT_SELECT_MODE_MAX on failure.
  *
+ * @param[in] obj The object.
+ *
  * @return The selected mode.
  *
  * @ingroup Elm_Genlist_Item
@@ -289,17 +277,48 @@ EAPI Elm_Object_Select_Mode elm_genlist_item_select_mode_get(const Elm_Genlist_I
  * This function returns the item's type. Normally the item's type. If it
  * failed, return value is ELM_GENLIST_ITEM_MAX.
  *
+ * @param[in] obj The object.
+ *
  * @return Item type.
  *
  * @ingroup Elm_Genlist_Item
  */
 EAPI Elm_Genlist_Item_Type elm_genlist_item_type_get(const Elm_Genlist_Item *obj);
 
+/**
+ * @brief Set whether a given genlist item is pinned or not
+ *
+ * This sets a genlist item as pinned so that it will be always available in
+ * the viewport available for user interaction. Group items cannot be pinned.
+ * Also when a new item is pinned, the current pinned item will get unpinned.
+ * Item pinning cannot be done in reorder mode too.
+ *
+ * @param[in] obj The object.
+ * @param[in] pin The item pin state state ($true pin item, @c false unpin
+ * item).
+ *
+ * @ingroup Elm_Genlist_Item
+ */
+EAPI void elm_genlist_item_pin_set(Elm_Genlist_Item *obj, Eina_Bool pin);
+
+/**
+ * @brief Get whether a given genlist item is pinned or not.
+ *
+ * @param[in] obj The object.
+ *
+ * @return The item pin state state ($true pin item, @c false unpin item).
+ *
+ * @ingroup Elm_Genlist_Item
+ */
+EAPI Eina_Bool elm_genlist_item_pin_get(const Elm_Genlist_Item *obj);
+
 /**
  * @brief Get the number of subitems of a given item.
  *
  * This returns the number of subitems that an item possesses.
  *
+ * @param[in] obj The object.
+ *
  * @return The number of subitems, 0 on error.
  *
  * @since 1.9
@@ -313,6 +332,7 @@ EAPI unsigned int elm_genlist_item_subitems_count(Elm_Genlist_Item *obj);
  *
  * This removes all items that are children (and their descendants) of the
  * given item @c it.
+ * @param[in] obj The object.
  *
  * @ingroup Elm_Genlist_Item
  */
@@ -337,6 +357,7 @@ EAPI void elm_genlist_item_demote(Elm_Genlist_Item *obj);
  * This causes genlist to jump to the given item @c it and show it (by jumping
  * to that position), if it is not fully visible.
  *
+ * @param[in] obj The object.
  * @param[in] type The position to bring in, the given item to. @ref
  * Elm_Genlist_Item_Scrollto_Type.
  *
@@ -352,6 +373,7 @@ EAPI void elm_genlist_item_show(Elm_Genlist_Item *obj, Elm_Genlist_Item_Scrollto
  * animatedly scrolling), if it is not fully visible. This may use animation
  * and take a some time to do so.
  *
+ * @param[in] obj The object.
  * @param[in] type The position to bring in, the given item to. @ref
  * Elm_Genlist_Item_Scrollto_Type.
  *
@@ -366,6 +388,7 @@ EAPI void elm_genlist_item_bring_in(Elm_Genlist_Item *obj, Elm_Genlist_Item_Scro
  * meaning that they will no longer be managed by genlist and are floating
  * "orphans" that can be re-used elsewhere if the user wants to.
  *
+ * @param[in] obj The object.
  * @param[out] l The contents list to return.
  *
  * @ingroup Elm_Genlist_Item
@@ -387,6 +410,7 @@ EAPI void elm_genlist_item_all_contents_unset(Elm_Genlist_Item *obj, Eina_List *
  * will be ignored because edje_object is deleted and created again by this
  * API. If you want to avoid this, please use @ref
  * elm_genlist_item_fields_update.
+ * @param[in] obj The object.
  *
  * @ingroup Elm_Genlist_Item
  */
@@ -403,6 +427,7 @@ EAPI void elm_genlist_item_update(Elm_Genlist_Item *obj);
  *
  * Use @ref elm_genlist_realized_items_update to update an item's all property.
  *
+ * @param[in] obj The object.
  * @param[in] parts The name of item's part.
  * @param[in] itf The type of item's part type.
  *
@@ -417,6 +442,7 @@ EAPI void elm_genlist_item_fields_update(Elm_Genlist_Item *obj, const char *part
  * After changing the item class @ref elm_genlist_item_update is called on the
  * item @c it.
  *
+ * @param[in] obj The object.
  * @param[in] itc The item class for the item.
  *
  * @ingroup Elm_Genlist_Item
@@ -452,6 +478,7 @@ EAPI void elm_genlist_item_item_class_update(Elm_Genlist_Item *obj, const Elm_Ge
  * active for that item while the mode is active on the item, and will be
  * destroyed after the mode is totally deactivated from that item.
  *
+ * @param[in] obj The object.
  * @param[in] decorate_it_type Mode name.
  * @param[in] decorate_it_set Boolean to define set or unset mode.
  *
