@@ -11,32 +11,6 @@ typedef Eo Elm_Map;
 #ifndef _ELM_MAP_EO_TYPES
 #define _ELM_MAP_EO_TYPES
 
-/**
- * @brief Set map's zoom behavior. It can be set to manual or automatic.
- *
- * Default value is #ELM_MAP_ZOOM_MODE_MANUAL.
- *
- * Values <b> don't </b> work as bitmask, only one can be chosen.
- *
- * Valid sizes are 2^zoom, consequently the map may be smaller than the
- * scroller view.
- *
- * See @ref elm_map_zoom_mode_set() See @ref elm_map_zoom_mode_get()
- *
- * @ingroup Elm_Map
- */
-typedef enum
-{
-  ELM_MAP_ZOOM_MODE_MANUAL = 0, /**< Zoom controlled manually by
-                                 * elm_map_zoom_set(). It's set by default. */
-  ELM_MAP_ZOOM_MODE_AUTO_FIT, /**< Zoom until map fits inside the scroll frame
-                               * with no pixels outside this area. */
-  ELM_MAP_ZOOM_MODE_AUTO_FILL, /**< Zoom until map fills scroll, ensuring no
-                                * pixels are left unfilled. */
-  ELM_MAP_ZOOM_MODE_LAST /**< Sentinel value to indicate last enum field during
-                          * iteration */
-} Elm_Map_Zoom_Mode;
-
 /**
  * @brief Set type of a external source (provider).
  *
@@ -90,41 +64,6 @@ typedef enum
 
 #endif
 
-/**
- * @brief Set the zoom level of the map.
- *
- * This sets the zoom level.
- *
- * It will respect limits defined by @ref elm_map_zoom_min_set and
- * @ref elm_map_zoom_max_set.
- *
- * By default these values are 0 (world map) and 18 (maximum zoom).
- *
- * This function should be used when zoom mode is set to
- * #ELM_MAP_ZOOM_MODE_MANUAL. This is the default mode, and can be set with
- * @ref elm_map_zoom_mode_set.
- *
- * @param[in] zoom The zoom level.
- *
- * @ingroup Elm_Map
- */
-EAPI void elm_map_zoom_set(Elm_Map *obj, int zoom);
-
-/**
- * @brief Get the zoom level of the map.
- *
- * This returns the current zoom level of the map object.
- *
- * Note that if you set the fill mode to other than #ELM_MAP_ZOOM_MODE_MANUAL
- * (which is the default), the zoom level may be changed at any time by the map
- * object itself to account for map size and map viewport size.
- *
- * @return The zoom level.
- *
- * @ingroup Elm_Map
- */
-EAPI int elm_map_zoom_get(const Elm_Map *obj);
-
 /**
  * @brief Pause or unpause the map.
  *
@@ -135,6 +74,7 @@ EAPI int elm_map_zoom_get(const Elm_Map *obj);
  * This will stop zooming using animation, changing zoom levels will change
  * instantly. This will stop any existing animations that are running.
  *
+ * @param[in] obj The object.
  * @param[in] paused Use @c true to pause the map @c obj or @c false to unpause
  * it.
  *
@@ -147,38 +87,18 @@ EAPI void elm_map_paused_set(Elm_Map *obj, Eina_Bool paused);
  *
  * This gets the current paused state for the map object.
  *
+ * @param[in] obj The object.
+ *
  * @return Use @c true to pause the map @c obj or @c false to unpause it.
  *
  * @ingroup Elm_Map
  */
 EAPI Eina_Bool elm_map_paused_get(const Elm_Map *obj);
 
-/**
- * @brief Enable or disable mouse wheel to be used to zoom in / out the map.
- *
- * Wheel is enabled by default.
- *
- * @param[in] disabled Use @c true to disable mouse wheel or @c false to enable
- * it.
- *
- * @ingroup Elm_Map
- */
-EAPI void elm_map_wheel_disabled_set(Elm_Map *obj, Eina_Bool disabled);
-
-/**
- * @brief Get a value whether mouse wheel is enabled or not.
- *
- * Mouse wheel can be used for the user to zoom in or zoom out the map.
- *
- * @return Use @c true to disable mouse wheel or @c false to enable it.
- *
- * @ingroup Elm_Map
- */
-EAPI Eina_Bool elm_map_wheel_disabled_get(const Elm_Map *obj);
-
 /**
  * @brief Set the minimum zoom of the source.
  *
+ * @param[in] obj The object.
  * @param[in] zoom Minimum zoom value to be used.
  *
  * @ingroup Elm_Map
@@ -188,6 +108,8 @@ EAPI void elm_map_zoom_min_set(Elm_Map *obj, int zoom);
 /**
  * @brief Get the minimum zoom of the source.
  *
+ * @param[in] obj The object.
+ *
  * @return Minimum zoom value to be used.
  *
  * @ingroup Elm_Map
@@ -197,6 +119,7 @@ EAPI int elm_map_zoom_min_get(const Elm_Map *obj);
 /**
  * @brief Rotate the map.
  *
+ * @param[in] obj The object.
  * @param[in] degree Angle from 0.0 to 360.0 to rotate around Z axis.
  * @param[in] cx Rotation's center horizontal position.
  * @param[in] cy Rotation's center vertical position.
@@ -208,6 +131,7 @@ EAPI void elm_map_rotate_set(Elm_Map *obj, double degree, int cx, int cy);
 /**
  * @brief Get the rotate degree of the map.
  *
+ * @param[in] obj The object.
  * @param[out] degree Angle from 0.0 to 360.0 to rotate around Z axis.
  * @param[out] cx Rotation's center horizontal position.
  * @param[out] cy Rotation's center vertical position.
@@ -225,6 +149,7 @@ EAPI void elm_map_rotate_get(const Elm_Map *obj, double *degree, int *cx, int *c
  * The @c user_agent identification string will transmitted in a header field
  * @c User-Agent.
  *
+ * @param[in] obj The object.
  * @param[in] user_agent The user agent to be used by the map.
  *
  * @ingroup Elm_Map
@@ -234,6 +159,8 @@ EAPI void elm_map_user_agent_set(Elm_Map *obj, const char *user_agent);
 /**
  * @brief Get the user agent used by the map object.
  *
+ * @param[in] obj The object.
+ *
  * @return The user agent to be used by the map.
  *
  * @ingroup Elm_Map
@@ -243,6 +170,7 @@ EAPI const char *elm_map_user_agent_get(const Elm_Map *obj);
 /**
  * @brief Set the maximum zoom of the source.
  *
+ * @param[in] obj The object.
  * @param[in] zoom Maximum zoom value to be used.
  *
  * @ingroup Elm_Map
@@ -252,53 +180,21 @@ EAPI void elm_map_zoom_max_set(Elm_Map *obj, int zoom);
 /**
  * @brief Get the maximum zoom of the source.
  *
+ * @param[in] obj The object.
+ *
  * @return Maximum zoom value to be used.
  *
  * @ingroup Elm_Map
  */
 EAPI int elm_map_zoom_max_get(const Elm_Map *obj);
 
-/**
- * @brief Set the zoom mode used by the map object.
- *
- * This sets the zoom mode to manual or one of the automatic levels. Manual
- * (#ELM_MAP_ZOOM_MODE_MANUAL) means that zoom is set manually by
- * @ref elm_map_zoom_mode_set and will stay at that level until changed by code
- * or until zoom mode is changed. This is the default mode.
- *
- * The Automatic modes will allow the map object to automatically adjust zoom
- * mode based on properties. #ELM_MAP_ZOOM_MODE_AUTO_FIT will adjust zoom so
- * the map fits inside the scroll frame with no pixels outside this area.
- * #ELM_MAP_ZOOM_MODE_AUTO_FILL will be similar but ensure no pixels within the
- * frame are left unfilled. Do not forget that the valid sizes are 2^zoom,
- * consequently the map may be smaller than the scroller view.
- *
- * @param[in] mode The zoom mode of the map, being it one of
- * #ELM_MAP_ZOOM_MODE_MANUAL (default), #ELM_MAP_ZOOM_MODE_AUTO_FIT, or
- * #ELM_MAP_ZOOM_MODE_AUTO_FILL.
- *
- * @ingroup Elm_Map
- */
-EAPI void elm_map_zoom_mode_set(Elm_Map *obj, Elm_Map_Zoom_Mode mode);
-
-/**
- * @brief Get the zoom mode used by the map object.
- *
- * This function returns the current zoom mode used by the ma object.
- *
- * @return The zoom mode of the map, being it one of #ELM_MAP_ZOOM_MODE_MANUAL
- * (default), #ELM_MAP_ZOOM_MODE_AUTO_FIT, or #ELM_MAP_ZOOM_MODE_AUTO_FILL.
- *
- * @ingroup Elm_Map
- */
-EAPI Elm_Map_Zoom_Mode elm_map_zoom_mode_get(const Elm_Map *obj);
-
 /**
  * @brief Get the current geographic coordinates of the map.
  *
  * This gets the current center coordinates of the map object. It can be set by
  * @ref elm_map_region_bring_in and @ref elm_map_region_show.
  *
+ * @param[in] obj The object.
  * @param[out] lon Pointer to store longitude.
  * @param[out] lat Pointer to store latitude.
  *
@@ -312,6 +208,8 @@ EAPI void elm_map_region_get(const Elm_Map *obj, double *lon, double *lat);
  * This list includes group overlays also. So this can be changed dynamically
  * while zooming and panning.
  *
+ * @param[in] obj The object.
+ *
  * @return The list of all overlays or @c null upon failure.
  *
  * @since 1.7
@@ -325,6 +223,7 @@ EAPI Eina_List *elm_map_overlays_get(const Elm_Map *obj);
  *
  * This gets the current tile loaded status for the map object.
  *
+ * @param[in] obj The object.
  * @param[out] try_num Pointer to store number of tiles download requested.
  * @param[out] finish_num Pointer to store number of tiles successfully
  * downloaded.
@@ -352,6 +251,7 @@ EAPI void elm_map_tile_load_status_get(const Elm_Map *obj, int *try_num, int *fi
  *
  * The current source can be get using @ref elm_map_source_get.
  *
+ * @param[in] obj The object.
  * @param[in] type Source type.
  * @param[in] source_name The source to be used.
  *
@@ -362,6 +262,7 @@ EAPI void elm_map_source_set(Elm_Map *obj, Elm_Map_Source_Type type, const char
 /**
  * @brief Get the name of currently used source for a specific type.
  *
+ * @param[in] obj The object.
  * @param[in] type Source type.
  *
  * @return The name of the source in use.
@@ -389,6 +290,7 @@ EAPI const char *elm_map_source_get(const Elm_Map *obj, Elm_Map_Source_Type type
  * Routes created with this method can be deleted with @ref elm_map_route_del
  * and distance can be get with @ref elm_map_route_distance_get.
  *
+ * @param[in] obj The object.
  * @param[in] type The type of transport to be considered when tracing a route.
  * @param[in] method The routing method, what should be prioritized.
  * @param[in] flon The start longitude.
@@ -407,6 +309,7 @@ EAPI Elm_Map_Route *elm_map_route_add(Elm_Map *obj, Elm_Map_Route_Type type, Elm
 /**
  * @brief Add a track on the map.
  *
+ * @param[in] obj The object.
  * @param[in] emap The emap route object.
  *
  * @return The route object. This is an elm object of type Route.
@@ -422,6 +325,7 @@ EAPI Efl_Canvas_Object *elm_map_track_add(Elm_Map *obj, void *emap);
  * This gets canvas x, y coordinates from longitude and latitude. The canvas
  * coordinates mean x, y coordinate from current viewport.
  *
+ * @param[in] obj The object.
  * @param[in] lon The longitude to convert.
  * @param[in] lat The latitude to convert.
  * @param[out] x A pointer to horizontal coordinate.
@@ -438,6 +342,7 @@ EAPI void elm_map_region_to_canvas_convert(const Elm_Map *obj, double lon, doubl
  * Overlay created with this method can be deleted with @ref
  * elm_map_overlay_del.
  *
+ * @param[in] obj The object.
  * @param[in] lon The center longitude.
  * @param[in] lat The center latitude.
  * @param[in] radius The pixel length of radius.
@@ -464,6 +369,8 @@ EAPI Elm_Map_Overlay *elm_map_overlay_circle_add(Elm_Map *obj, double lon, doubl
  * Also these changes have a influence on the overlays in the same class even
  * if each overlay is alone and is not grouped.
  *
+ * @param[in] obj The object.
+ *
  * @return The created overlay or @c null upon failure.
  *
  * @ingroup Elm_Map
@@ -482,6 +389,8 @@ EAPI Elm_Map_Overlay *elm_map_overlay_class_add(Elm_Map *obj);
  * Overlay created with this method can be deleted with @ref
  * elm_map_overlay_del.
  *
+ * @param[in] obj The object.
+ *
  * @return The created overlay or @c null upon failure.
  *
  * @ingroup Elm_Map
@@ -501,6 +410,7 @@ EAPI Elm_Map_Overlay *elm_map_overlay_bubble_add(Elm_Map *obj);
  *
  * At least available sources of name type are "Nominatim".
  *
+ * @param[in] obj The object.
  * @param[in] type Source type.
  *
  * @return The char pointer array of source names.
@@ -518,6 +428,8 @@ EAPI const char **elm_map_sources_get(const Elm_Map *obj, Elm_Map_Source_Type ty
  * Overlay created with this method can be deleted with @ref
  * elm_map_overlay_del.
  *
+ * @param[in] obj The object.
+ *
  * @return The created overlay or @c null upon failure.
  *
  * @ingroup Elm_Map
@@ -531,6 +443,7 @@ EAPI Elm_Map_Overlay *elm_map_overlay_polygon_add(Elm_Map *obj);
  * Overlay created with this method can be deleted with  @ref
  * elm_map_overlay_del.
  *
+ * @param[in] obj The object.
  * @param[in] flon The start longitude.
  * @param[in] flat The start latitude.
  * @param[in] tlon The destination longitude.
@@ -550,6 +463,7 @@ EAPI Elm_Map_Overlay *elm_map_overlay_line_add(Elm_Map *obj, double flon, double
  *
  * See @ref elm_map_region_bring_in for a function to move with animation.
  *
+ * @param[in] obj The object.
  * @param[in] lon Longitude to center at.
  * @param[in] lat Latitude to center at.
  *
@@ -570,6 +484,7 @@ EAPI void elm_map_region_show(Elm_Map *obj, double lon, double lat);
  *
  * To get the longitude and latitude, @ref elm_map_region_get should be used.
  *
+ * @param[in] obj The object.
  * @param[in] address The address.
  * @param[in] lon The longitude.
  * @param[in] lat The latitude.
@@ -587,6 +502,7 @@ EAPI Elm_Map_Name *elm_map_name_add(const Elm_Map *obj, const char *address, dou
  *
  * @internal
  *
+ * @param[in] obj The object.
  * @param[in] address The address.
  * @param[in] name_cb The callback function.
  * @param[in] data The user callback data.
@@ -607,6 +523,7 @@ EAPI void elm_map_name_search(const Elm_Map *obj, const char *address, Elm_Map_N
  *
  * See @ref elm_map_region_show for a function to avoid animation.
  *
+ * @param[in] obj The object.
  * @param[in] lon Longitude to center at.
  * @param[in] lat Latitude to center at.
  *
@@ -624,6 +541,7 @@ EAPI void elm_map_region_bring_in(Elm_Map *obj, double lon, double lat);
  *
  * See also @ref elm_map_region_bring_in.
  *
+ * @param[in] obj The object.
  * @param[in] zoom The zoom level to set.
  * @param[in] lon Longitude to center at.
  * @param[in] lat Latitude to center at.
@@ -637,6 +555,7 @@ EAPI void elm_map_region_zoom_bring_in(Elm_Map *obj, int zoom, double lon, doubl
 /**
  * @brief Remove a track from the map.
  *
+ * @param[in] obj The object.
  * @param[in] route The track to remove.
  *
  * @ingroup Elm_Map
@@ -654,6 +573,7 @@ EAPI void elm_map_track_remove(Elm_Map *obj, Efl_Canvas_Object *route);
  * Overlay created with this method can be deleted with @ref
  * elm_map_overlay_del.
  *
+ * @param[in] obj The object.
  * @param[in] route The route object to make a overlay.
  *
  * @return The created overlay or @c null upon failure.
@@ -672,6 +592,7 @@ EAPI Elm_Map_Overlay *elm_map_overlay_route_add(Elm_Map *obj, const Elm_Map_Rout
  * Overlay created with this method can be deleted with @ref
  * elm_map_overlay_del.
  *
+ * @param[in] obj The object.
  * @param[in] x horizontal pixel coordinate.
  * @param[in] y vertical pixel coordinate.
  *
@@ -696,6 +617,7 @@ EAPI Elm_Map_Overlay *elm_map_overlay_scale_add(Elm_Map *obj, int x, int y);
  *
  * Overlay created with this method can be deleted by @ref elm_map_overlay_del.
  *
+ * @param[in] obj The object.
  * @param[in] lon The longitude of the overlay.
  * @param[in] lat The latitude of the overlay.
  *
@@ -712,6 +634,7 @@ EAPI Elm_Map_Overlay *elm_map_overlay_add(Elm_Map *obj, double lon, double lat);
  * This gets longitude and latitude from canvas x, y coordinates. The canvas
  * coordinates mean x, y coordinate from current viewport.
  *
+ * @param[in] obj The object.
  * @param[in] x Horizontal coordinate of the point to convert.
  * @param[in] y Vertical coordinate of the point to convert.
  * @param[out] lon A pointer to the longitude.
