@@ -14,13 +14,13 @@ typedef Eo Efl_Canvas_Group;
 
 #endif
 /**
- * @brief A group object is a container of other canvas objects. Its children
- * move along their parent, are often clipped with a common clipper. This is
+ * @brief A group object is a container for other canvas objects. Its children
+ * move along their parent and are often clipped with a common clipper. This is
  * part of the legacy smart object concept.
  *
- * A group is not necessarily a container (see @c Efl.Container), in the sense
- * that a standard widget may not have any empty slots for content, but is
- * still a group of low-level canvas objects (clipper, raw objects, etc...).
+ * A group is not necessarily a container (see @ref Efl_Container) in the sense
+ * that a standard widget may not have any empty slots for content. However
+ * it's still a group of low-level canvas objects (clipper, raw objects, etc.).
  *
  * @ingroup Efl_Canvas_Group
  */
@@ -29,19 +29,20 @@ typedef Eo Efl_Canvas_Group;
 EWAPI const Efl_Class *efl_canvas_group_class_get(void);
 
 /**
- * @brief Indicates that the group's layout need to be recalculated.
+ * @brief Indicates that the group's layout needs to be recalculated.
  *
  * If this flag is set, then the @ref efl_canvas_group_calculate function will
  * be called, during rendering phase of the canvas. After that, this flag will
  * be automatically unset.
  *
- * @note just setting this flag will not make the canvas' whole scene dirty, by
- * itself, and evas_render() will have no effect. To force that, use
- * @ref efl_canvas_group_change, that will also call this function
- * automatically, with @c true as parameter.
+ * @note setting this flag alone will not make the canvas' whole scene dirty.
+ * Using evas_render() will have no effect. To force this, use
+ * @ref efl_canvas_group_change, which will also call this function
+ * automatically, with the parameter set to @c true.
  *
  * See also @ref efl_canvas_group_calculate.
  *
+ * @param[in] obj The object.
  * @param[in] value @c true if the group layout needs to be recalculated,
  * @c false otherwise
  *
@@ -50,19 +51,21 @@ EWAPI const Efl_Class *efl_canvas_group_class_get(void);
 EOAPI void efl_canvas_group_need_recalculate_set(Eo *obj, Eina_Bool value);
 
 /**
- * @brief Indicates that the group's layout need to be recalculated.
+ * @brief Indicates that the group's layout needs to be recalculated.
  *
  * If this flag is set, then the @ref efl_canvas_group_calculate function will
  * be called, during rendering phase of the canvas. After that, this flag will
  * be automatically unset.
  *
- * @note just setting this flag will not make the canvas' whole scene dirty, by
- * itself, and evas_render() will have no effect. To force that, use
- * @ref efl_canvas_group_change, that will also call this function
- * automatically, with @c true as parameter.
+ * @note setting this flag alone will not make the canvas' whole scene dirty.
+ * Using evas_render() will have no effect. To force this, use
+ * @ref efl_canvas_group_change, which will also call this function
+ * automatically, with the parameter set to @c true.
  *
  * See also @ref efl_canvas_group_calculate.
  *
+ * @param[in] obj The object.
+ *
  * @return @c true if the group layout needs to be recalculated, @c false
  * otherwise
  *
@@ -76,6 +79,7 @@ EOAPI Eina_Bool efl_canvas_group_need_recalculate_get(const Eo *obj);
  * This also forcefully marks the given object as needing recalculation. As an
  * effect, on the next rendering cycle its @ref efl_canvas_group_calculate
  * method will be called.
+ * @param[in] obj The object.
  *
  * @ingroup Efl_Canvas_Group
  */
@@ -85,38 +89,44 @@ EOAPI void efl_canvas_group_change(Eo *obj);
  * @brief Triggers an immediate recalculation of this object's geometry.
  *
  * This will also reset the flag @ref efl_canvas_group_need_recalculate_get.
+ * @param[in] obj The object.
  *
  * @ingroup Efl_Canvas_Group
  */
 EOAPI void efl_canvas_group_calculate(Eo *obj);
 
 /**
- * @brief Returns an iterator over the children of this object, that are canvas
- * objects.
+ * @brief Returns an iterator over the children of this object, which are
+ * canvas objects.
  *
  * This returns the list of "smart" children. This might be different from both
- * the @c Efl.Object children list as well as the @c Efl.Container content
+ * the @ref Efl_Object children list as well as the @ref Efl_Container content
  * list.
  *
+ * @param[in] obj The object.
+ *
  * @return Iterator to object children
  *
  * @ingroup Efl_Canvas_Group
  */
-EOAPI Eina_Iterator *efl_canvas_group_children_iterate(const Eo *obj);
+EOAPI Eina_Iterator *efl_canvas_group_members_iterate(const Eo *obj);
 
 /**
- * @brief Set an Evas object as a member of a given smart object.
+ * @brief Set a canvas object as a member of a given group (or smart object).
  *
  * Members will automatically be stacked and layered together with the smart
  * object. The various stacking functions will operate on members relative to
  * the other members instead of the entire canvas, since they now live on an
- * exclusive layer (see evas_object_stack_above(), for more details).
+ * exclusive layer (see @ref efl_gfx_stack_above(), for more details).
  *
- * Any @c smart_obj object's specific implementation of the @c member_add()
- * smart function will take place too, naturally.
+ * Subclasses inheriting from this one may override this function to ensure the
+ * proper stacking of special objects, such as clippers, event rectangles,
+ * etc...
  *
- * See also @ref efl_canvas_group_member_del.
+ * See also @ref efl_canvas_group_member_del. See also
+ * @ref efl_canvas_group_member_is.
  *
+ * @param[in] obj The object.
  * @param[in] sub_obj The member object.
  *
  * @ingroup Efl_Canvas_Group
@@ -130,12 +140,44 @@ EOAPI void efl_canvas_group_member_add(Eo *obj, Efl_Canvas_Object *sub_obj) EINA
  * The object will still be on the canvas, but no longer associated with
  * whichever smart object it was associated with.
  *
- * See also @ref efl_canvas_group_member_add for more details.
+ * See also @ref efl_canvas_group_member_add. See also
+ * @ref efl_canvas_group_member_is.
  *
- * @param[in] sub_obj The member object.
+ * @param[in] obj The object.
+ * @param[in] sub_obj The member object to remove.
  *
  * @ingroup Efl_Canvas_Group
  */
 EOAPI void efl_canvas_group_member_del(Eo *obj, Efl_Canvas_Object *sub_obj);
 
+/**
+ * @brief Finds out if a given object is a member of this group.
+ *
+ * @param[in] obj The object.
+ * @param[in] sub_obj A potential sub object.
+ *
+ * @return @c true if @c sub_obj is a member of this group.
+ *
+ * @ingroup Efl_Canvas_Group
+ */
+EOAPI Eina_Bool efl_canvas_group_member_is(const Eo *obj, const Efl_Canvas_Object *sub_obj);
+
+#ifdef EFL_CANVAS_GROUP_PROTECTED
+/**
+ * @brief The internal clipper object used by this group.
+ *
+ * This is the object clipping all the child objects. Do not delete or
+ * otherwise modify this clipper!
+ *
+ * Get the internal clipper.
+ *
+ * @param[in] obj The object.
+ *
+ * @return A clipper rectangle.
+ *
+ * @ingroup Efl_Canvas_Group
+ */
+EOAPI const Efl_Canvas_Object *efl_canvas_group_clipper_get(const Eo *obj);
+#endif
+
 #endif
