@@ -19,6 +19,7 @@ typedef Eo Evas_Canvas;
  *
  * This function sets the image cache of canvas in bytes.
  *
+ * @param[in] obj The object.
  * @param[in] size The cache size.
  *
  * @ingroup Evas_Canvas
@@ -30,6 +31,8 @@ EAPI void evas_image_cache_set(Evas_Canvas *obj, int size);
  *
  * This function returns the image cache size of canvas in bytes.
  *
+ * @param[in] obj The object.
+ *
  * @return The cache size.
  *
  * @ingroup Evas_Canvas
@@ -39,10 +42,11 @@ EAPI int evas_image_cache_get(const Evas_Canvas *obj);
 /**
  * @brief Set the default set of flags an event begins with
  *
- * Events in evas can have an event_flags member. This starts out with  and
+ * Events in evas can have an event_flags member. This starts out with an
  * initial value (no flags). This lets you set the default flags that an event
- * begins with to be @c flags.
+ * begins with to @c flags.
  *
+ * @param[in] obj The object.
  * @param[in] flags The default flags to use.
  *
  * @since 1.2
@@ -56,6 +60,8 @@ EAPI void evas_event_default_flags_set(Evas_Canvas *obj, Efl_Input_Flags flags);
  *
  * This gets the default event flags events are produced with when fed in.
  *
+ * @param[in] obj The object.
+ *
  * @return The default flags to use.
  *
  * @since 1.2
@@ -67,6 +73,7 @@ EAPI Efl_Input_Flags evas_event_default_flags_get(const Evas_Canvas *obj);
 /**
  * @brief Changes the size of font cache of the given evas.
  *
+ * @param[in] obj The object.
  * @param[in] size The size in bytes.
  *
  * @ingroup Evas_Canvas
@@ -76,6 +83,8 @@ EAPI void evas_font_cache_set(Evas_Canvas *obj, int size);
 /**
  * @brief Get the size of font cache of the given evas in bytes.
  *
+ * @param[in] obj The object.
+ *
  * @return The size in bytes.
  *
  * @ingroup Evas_Canvas
@@ -85,6 +94,7 @@ EAPI int evas_font_cache_get(const Evas_Canvas *obj);
 /**
  * @brief Attaches a specific pointer to the evas for fetching later.
  *
+ * @param[in] obj The object.
  * @param[in] data The attached pointer.
  *
  * @ingroup Evas_Canvas
@@ -94,6 +104,8 @@ EAPI void evas_data_attach_set(Evas_Canvas *obj, void *data);
 /**
  * @brief Returns the pointer attached by @ref evas_data_attach_set.
  *
+ * @param[in] obj The object.
+ *
  * @return The attached pointer.
  *
  * @ingroup Evas_Canvas
@@ -120,6 +132,8 @@ EAPI void *evas_data_attach_get(const Evas_Canvas *obj);
  * @ref Efl.Canvas.Object.seat_focus_add,
  * @ref Efl.Canvas.Object.seat_focus_del.
  *
+ * @param[in] obj The object.
+ *
  * @return The object that has focus or @c null if there is not one.
  *
  * @ingroup Evas_Canvas
@@ -129,6 +143,7 @@ EAPI Efl_Canvas_Object *evas_focus_get(const Evas_Canvas *obj) EINA_WARN_UNUSED_
 /**
  * @brief Return the focused object by a given seat.
  *
+ * @param[in] obj The object.
  * @param[in] seat The seat to fetch the focused object or @c null for the
  * default seat.
  *
@@ -139,7 +154,7 @@ EAPI Efl_Canvas_Object *evas_focus_get(const Evas_Canvas *obj) EINA_WARN_UNUSED_
  *
  * @ingroup Evas_Canvas
  */
-EAPI Efl_Canvas_Object *evas_seat_focus_get(const Evas_Canvas *obj, Efl_Input_Device * seat);
+EAPI Efl_Canvas_Object *evas_seat_focus_get(const Evas_Canvas *obj, Efl_Input_Device *seat);
 
 /**
  * @brief Get the highest (stacked) Evas object on the canvas @c e.
@@ -153,6 +168,8 @@ EAPI Efl_Canvas_Object *evas_seat_focus_get(const Evas_Canvas *obj, Efl_Input_De
  * See also @ref evas_object_layer_get, @ref evas_object_layer_set, @ref
  * evas_object_below_get, @ref evas_object_above_get.
  *
+ * @param[in] obj The object.
+ *
  * @return A pointer to the highest object on it (if any) or @c null otherwise.
  *
  * @ingroup Evas_Canvas
@@ -162,6 +179,7 @@ EAPI Efl_Canvas_Object *evas_object_top_get(const Evas_Canvas *obj) EINA_WARN_UN
 /**
  * @brief This function returns the current known default pointer coordinates.
  *
+ * @param[in] obj The object.
  * @param[in] dev The pointer device.
  * @param[out] x The pointer to a Evas_Coord to be filled in.
  * @param[out] y The pointer to a Evas_Coord to be filled in.
@@ -170,7 +188,7 @@ EAPI Efl_Canvas_Object *evas_object_top_get(const Evas_Canvas *obj) EINA_WARN_UN
  *
  * @ingroup Evas_Canvas
  */
-EAPI void evas_pointer_canvas_xy_by_device_get(const Evas_Canvas *obj, Efl_Input_Device * dev, int *x, int *y);
+EAPI void evas_pointer_canvas_xy_by_device_get(const Evas_Canvas *obj, Efl_Input_Device *dev, int *x, int *y);
 
 /**
  * @brief This function returns the current known default pointer coordinates
@@ -180,6 +198,7 @@ EAPI void evas_pointer_canvas_xy_by_device_get(const Evas_Canvas *obj, Efl_Input
  * to contain these coordinates. If @c e is not a valid canvas the results of
  * this function are undefined.
  *
+ * @param[in] obj The object.
  * @param[out] x The pointer to a Evas_Coord to be filled in.
  * @param[out] y The pointer to a Evas_Coord to be filled in.
  *
@@ -190,6 +209,8 @@ EAPI void evas_pointer_canvas_xy_get(const Evas_Canvas *obj, int *x, int *y);
 /**
  * @brief Get the number of mouse or multi presses currently active.
  *
+ * @param[in] obj The object.
+ *
  * @return Mouse or multi presses currently active
  *
  * @since 1.2
@@ -203,12 +224,14 @@ EAPI int evas_event_down_count_get(const Evas_Canvas *obj);
  * calculations.
  *
  * Whenever evas performs smart object calculations on the whole canvas it
- * increments a counter by 1. This is the smart object calculate counter that
- * this function returns the value of. It starts at the value of 0 and will
- * increase (and eventually wrap around to negative values and so on) by 1
- * every time objects are calculated. You can use this counter to ensure you
- * don't re-do calculations withint the same calculation generation/run if the
- * calculations maybe cause self-feeding effects.
+ * increments a counter by 1. This function returns the value of the smart
+ * object calculate counter. It starts with a value of 0 and will increase (and
+ * eventually wrap around to negative values and so on) by 1 every time objects
+ * are calculated. You can use this counter to ensure you don't re-do
+ * calculations withint the same calculation generation/run if the calculations
+ * maybe cause self-feeding effects.
+ *
+ * @param[in] obj The object.
  *
  * @return Number of smart calculations
  *
@@ -221,6 +244,8 @@ EAPI int evas_smart_objects_calculate_count_get(const Evas_Canvas *obj);
 /**
  * @brief Get the focus state for the default seat.
  *
+ * @param[in] obj The object.
+ *
  * @return @c true if focused, @c false otherwise
  *
  * @ingroup Evas_Canvas
@@ -230,6 +255,7 @@ EAPI Eina_Bool evas_focus_state_get(const Evas_Canvas *obj);
 /**
  * @brief Get the focus state by a given seat.
  *
+ * @param[in] obj The object.
  * @param[in] seat The seat to check the focus state. Use @c null for the
  * default seat.
  *
@@ -237,11 +263,13 @@ EAPI Eina_Bool evas_focus_state_get(const Evas_Canvas *obj);
  *
  * @ingroup Evas_Canvas
  */
-EAPI Eina_Bool evas_seat_focus_state_get(const Evas_Canvas *obj, Efl_Input_Device * seat);
+EAPI Eina_Bool evas_seat_focus_state_get(const Evas_Canvas *obj, Efl_Input_Device *seat);
 
 /**
  * @brief Get the changed marker for the canvas.
  *
+ * @param[in] obj The object.
+ *
  * @return @c true if changed, @c false otherwise
  *
  * @since 1.11
@@ -253,6 +281,7 @@ EAPI Eina_Bool evas_changed_get(const Evas_Canvas *obj);
 /**
  * @brief This function returns the current known pointer coordinates.
  *
+ * @param[in] obj The object.
  * @param[in] dev The mouse device.
  * @param[out] x The pointer to an integer to be filled in.
  * @param[out] y The pointer to an integer to be filled in.
@@ -261,7 +290,7 @@ EAPI Eina_Bool evas_changed_get(const Evas_Canvas *obj);
  *
  * @ingroup Evas_Canvas
  */
-EAPI void evas_pointer_output_xy_by_device_get(const Evas_Canvas *obj, Efl_Input_Device * dev, int *x, int *y);
+EAPI void evas_pointer_output_xy_by_device_get(const Evas_Canvas *obj, Efl_Input_Device *dev, int *x, int *y);
 
 /**
  * @brief This function returns the current known default pointer coordinates.
@@ -271,6 +300,7 @@ EAPI void evas_pointer_output_xy_by_device_get(const Evas_Canvas *obj, Efl_Input
  * @c y to contain these coordinates. If @c e is not a valid canvas the results
  * of this function are undefined.
  *
+ * @param[in] obj The object.
  * @param[out] x The pointer to an integer to be filled in.
  * @param[out] y The pointer to an integer to be filled in.
  *
@@ -278,63 +308,6 @@ EAPI void evas_pointer_output_xy_by_device_get(const Evas_Canvas *obj, Efl_Input
  */
 EAPI void evas_pointer_output_xy_get(const Evas_Canvas *obj, int *x, int *y);
 
-/**
- * @brief Returns whether the mouse pointer is logically inside the canvas.
- *
- * @param[in] dev The pointer device.
- *
- * @return @c true if the pointer is inside, @c false otherwise.
- *
- * @since 1.19
- *
- * @ingroup Evas_Canvas
- */
-EAPI Eina_Bool evas_pointer_inside_by_device_get(const Evas_Canvas *obj, Efl_Input_Device * dev);
-
-/**
- * @brief Returns whether the default mouse pointer is logically inside the
- * canvas.
- *
- * When this function is called it will return a value of either @c false or
- * @c true, depending on if event_feed_mouse_in or event_feed_mouse_out have
- * been called to feed in a  mouse enter event into the canvas.
- *
- * A return value of @c true indicates the mouse is logically inside the
- * canvas, and @c false implies it is logically outside the canvas.
- *
- * A canvas begins with the mouse being assumed outside ($false).
- *
- * If @c e is not a valid canvas, the return value is undefined.
- *
- * @return @c true if the mouse pointer is inside the canvas, @c false
- * otherwise
- *
- * @ingroup Evas_Canvas
- */
-EAPI Eina_Bool evas_pointer_inside_get(const Evas_Canvas *obj) EINA_WARN_UNUSED_RESULT;
-
-/**
- * @brief Get the maximum image size evas can possibly handle.
- *
- * This function returns the largest image or surface size that evas can handle
- * in pixels, and if there is one, returns @c true. It returns @c false if no
- * extra constraint on maximum image size exists. You still should check the
- * return values of @c maxw and @c maxh as there may still be a limit, just a
- * much higher one.
- *
- * @param[out] maxw Pointer to hold the return value in pixels of the maximum
- * width.
- * @param[out] maxh Pointer to hold the return value in pixels of the maximum
- * height.
- *
- * @return @c true if it can handle the maximum image size, @c false otherwise
- *
- * @since 1.1
- *
- * @ingroup Evas_Canvas
- */
-EAPI Eina_Bool evas_image_max_size_get(const Evas_Canvas *obj, int *maxw, int *maxh);
-
 /**
  * @brief Get the lowest (stacked) Evas object on the canvas @c e.
  *
@@ -347,6 +320,8 @@ EAPI Eina_Bool evas_image_max_size_get(const Evas_Canvas *obj, int *maxw, int *m
  * See also @ref evas_object_layer_get, @ref evas_object_layer_set, @ref
  * evas_object_below_get, @ref evas_object_below_set.
  *
+ * @param[in] obj The object.
+ *
  * @return A pointer to the lowest object on it, if any, or @c null otherwise.
  *
  * @ingroup Evas_Canvas
@@ -356,22 +331,23 @@ EAPI Efl_Canvas_Object *evas_object_bottom_get(const Evas_Canvas *obj) EINA_WARN
 /**
  * @brief Returns a bitmask with the mouse buttons currently pressed, set to 1.
  *
+ * @param[in] obj The object.
  * @param[in] dev The mouse device.
  *
  * @return A bitmask of the currently depressed buttons on the canvas.
  *
  * @ingroup Evas_Canvas
  */
-EAPI unsigned int evas_pointer_button_down_mask_by_device_get(const Evas_Canvas *obj, Efl_Input_Device * dev);
+EAPI unsigned int evas_pointer_button_down_mask_by_device_get(const Evas_Canvas *obj, Efl_Input_Device *dev);
 
 /**
  * @brief Returns a bitmask with the default mouse buttons currently pressed,
  * set to 1.
  *
  * Calling this function will return a 32-bit integer with the appropriate bits
- * set to 1 that correspond to a mouse button being depressed. This limits Evas
- * to a mouse devices with a maximum of 32 buttons, but that is generally in
- * excess of any host system's pointing device abilities.
+ * set to 1, which correspond to a mouse button being depressed. This limits
+ * Evas to a mouse devices with a maximum of 32 buttons, but that is generally
+ * in excess of any host system's pointing device abilities.
  *
  * A canvas by default begins with no mouse buttons being pressed and only
  * pointer move events can alter that.
@@ -382,6 +358,8 @@ EAPI unsigned int evas_pointer_button_down_mask_by_device_get(const Evas_Canvas
  *
  * If @c e is not a valid canvas, the return value is undefined.
  *
+ * @param[in] obj The object.
+ *
  * @return A bitmask of the currently depressed buttons on the canvas.
  *
  * @ingroup Evas_Canvas
@@ -397,6 +375,7 @@ EAPI unsigned int evas_pointer_button_down_mask_get(const Evas_Canvas *obj) EINA
  * enter the smart objects. It will not append to the list pass events as
  * hidden objects. Call eina_list_free on the returned list after usage.
  *
+ * @param[in] obj The object.
  * @param[in] stop An Evas Object where to stop searching.
  * @param[in] x The horizontal coordinate of the position.
  * @param[in] y The vertical coordinate of the position.
@@ -418,6 +397,7 @@ EAPI Eina_List *evas_tree_objects_at_xy_get(Evas_Canvas *obj, Efl_Canvas_Object
  * @ref evas_key_lock_del, @ref evas_key_lock_off, @ref evas_seat_key_lock_on,
  * @ref evas_seat_key_lock_off.
  *
+ * @param[in] obj The object.
  * @param[in] keyname The name of the lock to enable.
  *
  * @ingroup Evas_Canvas
@@ -435,6 +415,7 @@ EAPI void evas_key_lock_on(Evas_Canvas *obj, const char *keyname) EINA_ARG_NONNU
  * @ref evas_key_lock_del, @ref evas_key_lock_off, @ref evas_key_lock_on,
  * @ref evas_seat_key_lock_off.
  *
+ * @param[in] obj The object.
  * @param[in] keyname The name of the lock to enable.
  * @param[in] seat The seat to enable the keylock. A @c null seat repesents the
  * default seat.
@@ -455,6 +436,7 @@ EAPI void evas_seat_key_lock_on(Evas_Canvas *obj, const char *keyname, Efl_Input
  * See also @ref evas_key_lock_on, @ref evas_seat_key_lock_on,
  * @ref evas_key_lock_off.
  *
+ * @param[in] obj The object.
  * @param[in] keyname The name of the lock to enable.
  * @param[in] seat The seat to disable the keylock. A @c null seat repesents
  * the default seat.
@@ -468,9 +450,9 @@ EAPI void evas_seat_key_lock_off(Evas_Canvas *obj, const char *keyname, Efl_Inpu
 /**
  * @brief Adds the @c keyname key to the current list of modifier keys.
  *
- * Modifiers are keys like shift, alt and ctrl, i.e., keys which are meant to
- * be pressed together with others, altering the behavior of the secondly
- * pressed keys somehow. Evas is so that these keys can be user defined.
+ * Modifiers are keys like shift, alt and ctrl, i.e. keys which are meant to be
+ * pressed together with others, altering the behavior of the second keys
+ * pressed. Evas is so that these keys can be user defined.
  *
  * This call allows custom modifiers to be added to the Evas system at run
  * time. It is then possible to set and unset modifier keys programmatically
@@ -483,6 +465,7 @@ EAPI void evas_seat_key_lock_off(Evas_Canvas *obj, const char *keyname, Efl_Inpu
  * registering on it all standard modifiers: "Shift", "Control", "Alt", "Meta",
  * "Hyper", "Super".
  *
+ * @param[in] obj The object.
  * @param[in] keyname The name of the modifier key to add to the list of Evas
  * modifiers.
  *
@@ -499,37 +482,13 @@ EAPI void evas_key_modifier_add(Evas_Canvas *obj, const char *keyname) EINA_ARG_
  * @ref evas_seat_key_modifier_off, @ref evas_key_modifier_is_set, @ref
  * evas_seat_key_modifier_is_set.
  *
+ * @param[in] obj The object.
  * @param[in] keyname The name of the modifier to disable.
  *
  * @ingroup Evas_Canvas
  */
 EAPI void evas_key_modifier_off(Evas_Canvas *obj, const char *keyname) EINA_ARG_NONNULL(2);
 
-/**
- * @brief Retrieve a list of Evas objects lying over a given position in a
- * canvas.
- *
- * This function will traverse all the layers of the given canvas, from top to
- * bottom, querying for objects with areas covering the given position. The
- * user can remove from query objects which are hidden and/or which are set to
- * pass events.
- *
- * @warning This function will skip objects parented by smart objects, acting
- * only on the ones at the "top level", with regard to object parenting.
- *
- * @param[in] x The horizontal coordinate of the position.
- * @param[in] y The vertical coordinate of the position.
- * @param[in] include_pass_events_objects Boolean flag to include or not
- * objects which pass events in this calculation.
- * @param[in] include_hidden_objects Boolean flag to include or not hidden
- * objects in this calculation.
- *
- * @return The list of Evas objects that are over the given position in @c e.
- *
- * @ingroup Evas_Canvas
- */
-EAPI Eina_List *evas_objects_at_xy_get(const Evas_Canvas *obj, int x, int y, Eina_Bool include_pass_events_objects, Eina_Bool include_hidden_objects) EINA_WARN_UNUSED_RESULT;
-
 /**
  * @brief Render the given Evas canvas asynchronously.
  *
@@ -545,6 +504,8 @@ EAPI Eina_List *evas_objects_at_xy_get(const Evas_Canvas *obj, int x, int y, Ein
  *
  * The list is given in the @c event_info parameter of the callback function.
  *
+ * @param[in] obj The object.
+ *
  * @return @c true if the canvas will render, @c false otherwise.
  *
  * @since 1.8
@@ -563,6 +524,8 @@ EAPI Eina_Bool evas_render_async(Evas_Canvas *obj);
  * know not to wait for the updates callback and just return to their main
  * loop.
  *
+ * @param[in] obj The object.
+ *
  * @return @c true if the canvas will render, @c false otherwise.
  *
  * @since 1.14
@@ -576,9 +539,10 @@ EAPI Eina_Bool evas_render2(Evas_Canvas *obj);
  *
  * This is experimental and will change over time until noted here.
  *
+ * @param[in] obj The object.
+ *
  * @return A newly allocated list of updated rectangles of the canvas
- * ($Eina.Rectangle structs). Free this list with @ref
- * evas_render_updates_free.
+ * ($Eina.Rect structs). Free this list with @ref evas_render_updates_free.
  *
  * @since 1.15
  *
@@ -586,7 +550,7 @@ EAPI Eina_Bool evas_render2(Evas_Canvas *obj);
  */
 EAPI Eina_List *evas_render2_updates(Evas_Canvas *obj) EINA_WARN_UNUSED_RESULT;
 
-/** Inform to the evas that it lost the focus from the default seat.
+/** Inform the evas that it lost the focus from the default seat.
  *
  * @ingroup Evas_Canvas
  */
@@ -599,6 +563,7 @@ EAPI void evas_focus_out(Evas_Canvas *obj);
  * This function updates the canvas internal objects not triggering
  * renderization. To force renderization function @ref evas_render should be
  * used.
+ * @param[in] obj The object.
  *
  * @ingroup Evas_Canvas
  */
@@ -612,6 +577,7 @@ EAPI void evas_norender(Evas_Canvas *obj);
  *
  * @warning Do not use this function unless you know what Evas exactly works
  * with "changed" state.
+ * @param[in] obj The object.
  *
  * @ingroup Evas_Canvas
  */
@@ -627,6 +593,7 @@ EAPI void evas_nochange_pop(Evas_Canvas *obj);
  * See also @ref evas_key_lock_on, @ref evas_seat_key_lock_on,
  * @ref evas_seat_key_lock_off.
  *
+ * @param[in] obj The object.
  * @param[in] keyname The name of the lock to disable.
  *
  * @ingroup Evas_Canvas
@@ -641,6 +608,7 @@ EAPI void evas_key_lock_off(Evas_Canvas *obj, const char *keyname) EINA_ARG_NONN
  *
  * @warning Do not use this function unless you know what Evas exactly works
  * with "changed" state.
+ * @param[in] obj The object.
  *
  * @ingroup Evas_Canvas
  */
@@ -652,32 +620,6 @@ EAPI void evas_nochange_push(Evas_Canvas *obj);
  */
 EAPI void evas_font_cache_flush(Evas_Canvas *obj);
 
-/**
- * @brief Retrieve the Evas object stacked at the top of a given position in a
- * canvas.
- *
- * This function will traverse all the layers of the given canvas, from top to
- * bottom, querying for objects with areas covering the given position. The
- * user can remove from the query objects which are hidden and/or which are set
- * to pass events.
- *
- * @warning This function will skip objects parented by smart objects, acting
- * only on the ones at the "top level", with regard to object parenting.
- *
- * @param[in] x The horizontal coordinate of the position.
- * @param[in] y The vertical coordinate of the position.
- * @param[in] include_pass_events_objects Boolean flag to include or not
- * objects which pass events in this calculation.
- * @param[in] include_hidden_objects Boolean flag to include or not hidden
- * objects in this calculation.
- *
- * @return The Evas object that is over all other objects at the given
- * position.
- *
- * @ingroup Evas_Canvas
- */
-EAPI Efl_Canvas_Object *evas_object_top_at_xy_get(const Evas_Canvas *obj, int x, int y, Eina_Bool include_pass_events_objects, Eina_Bool include_hidden_objects) EINA_WARN_UNUSED_RESULT;
-
 /**
  * @brief Enables or turns on programmatically the modifier key with name
  * @c keyname for the default seat.
@@ -688,6 +630,7 @@ EAPI Efl_Canvas_Object *evas_object_top_at_xy_get(const Evas_Canvas *obj, int x,
  * See also @ref evas_key_modifier_off, @ref evas_seat_key_modifier_on,
  * @ref evas_seat_key_modifier_off.
  *
+ * @param[in] obj The object.
  * @param[in] keyname The name of the modifier to enable.
  *
  * @ingroup Evas_Canvas
@@ -704,6 +647,7 @@ EAPI void evas_key_modifier_on(Evas_Canvas *obj, const char *keyname) EINA_ARG_N
  * See also @ref evas_key_modifier_off, @ref evas_seat_key_modifier_on,
  * @ref evas_seat_key_modifier_off.
  *
+ * @param[in] obj The object.
  * @param[in] keyname The name of the lock to enable.
  * @param[in] seat The seat to enable the modifier. A @c null seat repesents
  * the default seat.
@@ -723,6 +667,7 @@ EAPI void evas_seat_key_modifier_on(Evas_Canvas *obj, const char *keyname, Efl_I
  * @ref evas_seat_key_modifier_off, @ref evas_key_modifier_is_set, @ref
  * evas_seat_key_modifier_is_set.
  *
+ * @param[in] obj The object.
  * @param[in] keyname The name of the lock to enable.
  * @param[in] seat The seat to disable the modifier. A @c null seat repesents
  * the default seat.
@@ -740,6 +685,8 @@ EAPI void evas_seat_key_modifier_off(Evas_Canvas *obj, const char *keyname, Efl_
  * support, and the paths provided at runtime as explained in @ref
  * Evas_Font_Path_Group.
  *
+ * @param[in] obj The object.
+ *
  * @return A newly allocated list of strings. Do not change the strings. Be
  * sure to call @ref evas_font_available_list_free after you're done.
  *
@@ -747,24 +694,6 @@ EAPI void evas_seat_key_modifier_off(Evas_Canvas *obj, const char *keyname, Efl_
  */
 EAPI Eina_List *evas_font_available_list(const Evas_Canvas *obj) EINA_WARN_UNUSED_RESULT;
 
-/**
- * @brief Get all objects in the given rectangle
- *
- * @param[in] x X coordinate
- * @param[in] y Y coordinate
- * @param[in] w Width
- * @param[in] h Height
- * @param[in] include_pass_events_objects @c true if the list should include
- * objects which pass events
- * @param[in] include_hidden_objects @c true if the list should include hidden
- * objects
- *
- * @return List of objects
- *
- * @ingroup Evas_Canvas
- */
-EAPI Eina_List *evas_objects_in_rectangle_get(const Evas_Canvas *obj, int x, int y, int w, int h, Eina_Bool include_pass_events_objects, Eina_Bool include_hidden_objects) EINA_WARN_UNUSED_RESULT;
-
 /**
  * @brief Retrieves the object on the given evas with the given name.
  *
@@ -773,6 +702,7 @@ EAPI Eina_List *evas_objects_in_rectangle_get(const Evas_Canvas *obj, int x, int
  * that name is returned is undefined, so only use this if you can ensure the
  * object name is unique.
  *
+ * @param[in] obj The object.
  * @param[in] name The given name.
  *
  * @return If successful, the Evas object with the given name. Otherwise,
@@ -785,6 +715,7 @@ EAPI Efl_Canvas_Object *evas_object_name_find(const Evas_Canvas *obj, const char
 /**
  * @brief Appends a font path to the list of font paths used by the given evas.
  *
+ * @param[in] obj The object.
  * @param[in] path The new font path.
  *
  * @ingroup Evas_Canvas
@@ -797,28 +728,12 @@ EAPI void evas_font_path_append(Evas_Canvas *obj, const char *path) EINA_ARG_NON
  */
 EAPI void evas_font_path_clear(Evas_Canvas *obj);
 
-/** Call user-provided @c calculate smart functions and unset the flag
- * signalling that the object needs to get recalculated to all smart objects in
- * the canvas.
- *
- * @ingroup Evas_Canvas
- */
-EAPI void evas_smart_objects_calculate(Evas_Canvas *obj);
-
-/**
- * @brief Get if the canvas is currently calculating smart objects.
- *
- * @return @c true if currently calculating smart objects.
- *
- * @ingroup Evas_Canvas
- */
-EAPI Eina_Bool evas_smart_objects_calculating_get(const Evas_Canvas *obj);
-
 
 /**
  * @brief Removes the @c keyname key from the current list of lock keys on
  * canvas @c e.
  *
+ * @param[in] obj The object.
  * @param[in] keyname The name of the key to remove from the locks list.
  *
  * @ingroup Evas_Canvas
@@ -834,6 +749,7 @@ EAPI void evas_key_lock_del(Evas_Canvas *obj, const char *keyname) EINA_ARG_NONN
  * @note All newly created Evas rectangles get the default color values of 255
  * 255 255 255 (opaque white).
  *
+ * @param[in] obj The object.
  * @param[in] x The rectangle's left position.
  * @param[in] y The rectangle's top position.
  * @param[in] w The rectangle's width.
@@ -852,6 +768,8 @@ EAPI void evas_sync(Evas_Canvas *obj);
 /**
  * @brief Retrieves the list of font paths used by the given evas.
  *
+ * @param[in] obj The object.
+ *
  * @return The list of font paths used.
  *
  * @ingroup Evas_Canvas
@@ -862,6 +780,7 @@ EAPI const Eina_List *evas_font_path_list(const Evas_Canvas *obj) EINA_WARN_UNUS
  * @brief Reload the image cache.
  *
  * This function reloads the image cache of canvas.
+ * @param[in] obj The object.
  *
  * @ingroup Evas_Canvas
  */
@@ -875,6 +794,7 @@ EAPI void evas_image_cache_reload(Evas_Canvas *obj);
  * location, returning it as the function  return value. If @c e is invalid,
  * the results are undefined.
  *
+ * @param[in] obj The object.
  * @param[in] x The canvas X coordinate.
  *
  * @return The output/screen coordinate translated to output coordinates.
@@ -890,17 +810,18 @@ EAPI int evas_coord_world_x_to_screen(const Evas_Canvas *obj, int x) EINA_WARN_U
  * @c e.
  *
  * @note This is a very low level function, which most of Evas' users wouldn't
- * care about. One would use it, for example, to grab an Evas' canvas update
+ * care about. You might use it, for instance, to grab an Evas' canvas update
  * regions and paint them back, using the canvas' pixmap, on a displaying
  * system working below Evas.
  *
  * @note Evas is a stateful canvas. If no operations changing its state took
- * place since the last rendering action, you won't see no changes and this
+ * place since the last rendering action, you won't see any changes and this
  * call will be a no-op.
  *
+ * @param[in] obj The object.
+ *
  * @return A newly allocated list of updated rectangles of the canvas
- * ($Eina.Rectangle structs). Free this list with @ref
- * evas_render_updates_free.
+ * ($Eina.Rect structs). Free this list with @ref evas_render_updates_free.
  *
  * @ingroup Evas_Canvas
  */
@@ -910,6 +831,7 @@ EAPI Eina_List *evas_render_updates(Evas_Canvas *obj) EINA_WARN_UNUSED_RESULT;
  * @brief Flush the image cache of the canvas.
  *
  * This function flushes image cache of canvas.
+ * @param[in] obj The object.
  *
  * @ingroup Evas_Canvas
  */
@@ -923,6 +845,7 @@ EAPI void evas_image_cache_flush(Evas_Canvas *obj);
  * location, returning it as the function return value. If @c e is invalid, the
  * results are undefined.
  *
+ * @param[in] obj The object.
  * @param[in] y The screen/output y coordinate.
  *
  * @return The screen coordinate translated to canvas unit coordinates.
@@ -937,6 +860,7 @@ EAPI int evas_coord_screen_y_to_world(const Evas_Canvas *obj, int y) EINA_WARN_U
  *
  * See also @ref evas_key_modifier_add.
  *
+ * @param[in] obj The object.
  * @param[in] keyname The name of the key to remove from the modifiers list.
  *
  * @ingroup Evas_Canvas
@@ -982,6 +906,7 @@ EAPI void evas_focus_in(Evas_Canvas *obj);
  * you want to re-render it afterwards expecting new contents, you have to add
  * "damage" regions yourself (see @ref evas_damage_rectangle_add).
  *
+ * @param[in] obj The object.
  * @param[in] x The rectangle's top left corner's horizontal coordinate.
  * @param[in] y The rectangle's top left corner's vertical coordinate.
  * @param[in] w The rectangle's width.
@@ -995,46 +920,17 @@ EAPI void evas_obscured_rectangle_add(Evas_Canvas *obj, int x, int y, int w, int
  * @brief Make the canvas discard as much data as possible used by the engine
  * at runtime.
  *
- * This function will unload images, delete textures and much more, where
+ * This function will unload images, delete textures and much more where
  * possible. You may also want to call @ref evas_render_idle_flush immediately
  * prior to this to perhaps discard a little more, though this function should
  * implicitly delete most of what @ref evas_render_idle_flush might discard
  * too.
+ * @param[in] obj The object.
  *
  * @ingroup Evas_Canvas
  */
 EAPI void evas_render_dump(Evas_Canvas *obj);
 
-/**
- * @brief Retrieve the Evas object stacked at the top of a given rectangular
- * region in a canvas
- *
- * This function will traverse all the layers of the given canvas, from top to
- * bottom, querying for objects with areas overlapping with the given
- * rectangular region inside @c e. The user can remove from the query objects
- * which are hidden and/or which are set to pass events.
- *
- * @warning This function will skip objects parented by smart objects, acting
- * only on the ones at the "top level", with regard to object parenting.
- *
- * @param[in] x The top left corner's horizontal coordinate for the rectangular
- * region.
- * @param[in] y The top left corner's vertical coordinate for the rectangular
- * region.
- * @param[in] w The width of the rectangular region.
- * @param[in] h The height of the rectangular region.
- * @param[in] include_pass_events_objects Boolean flag to include or not
- * objects which pass events in this calculation.
- * @param[in] include_hidden_objects Boolean flag to include or not hidden
- * objects in this calculation.
- *
- * @return The Evas object that is over all other objects at the given
- * rectangular region.
- *
- * @ingroup Evas_Canvas
- */
-EAPI Efl_Canvas_Object *evas_object_top_in_rectangle_get(const Evas_Canvas *obj, int x, int y, int w, int h, Eina_Bool include_pass_events_objects, Eina_Bool include_hidden_objects) EINA_WARN_UNUSED_RESULT;
-
 /** Force renderization of the given canvas.
  *
  * @ingroup Evas_Canvas
@@ -1045,6 +941,7 @@ EAPI void evas_render(Evas_Canvas *obj);
  * @brief Prepends a font path to the list of font paths used by the given
  * evas.
  *
+ * @param[in] obj The object.
  * @param[in] path The new font path.
  *
  * @ingroup Evas_Canvas
@@ -1065,6 +962,7 @@ EAPI void evas_font_path_prepend(Evas_Canvas *obj, const char *path) EINA_ARG_NO
  * @note This function does not flag the canvas as having its state changed. If
  * you want to re-render it afterwards expecting new contents, you have to add
  * "damage" regions yourself (see @ref evas_damage_rectangle_add).
+ * @param[in] obj The object.
  *
  * @ingroup Evas_Canvas
  */
@@ -1078,6 +976,7 @@ EAPI void evas_obscured_clear(Evas_Canvas *obj);
  * location, returning it as the function return value. If @c e is invalid, the
  * results are undefined.
  *
+ * @param[in] obj The object.
  * @param[in] x The screen/output x coordinate.
  *
  * @return The screen coordinate translated to canvas unit coordinates.
@@ -1105,6 +1004,7 @@ EAPI int evas_coord_screen_x_to_world(const Evas_Canvas *obj, int x) EINA_WARN_U
  * registering on it all standard lock keys: "Caps_Lock", "Num_Lock",
  * "Scroll_Lock".
  *
+ * @param[in] obj The object.
  * @param[in] keyname The name of the key to add to the locks list.
  *
  * @ingroup Evas_Canvas
@@ -1117,6 +1017,7 @@ EAPI void evas_key_lock_add(Evas_Canvas *obj, const char *keyname) EINA_ARG_NONN
  * This function flushes the arrays of delete, active and render objects. Other
  * things it may also discard are: shared memory segments, temporary scratch
  * buffers, cached data to avoid re-compute of that data etc.
+ * @param[in] obj The object.
  *
  * @ingroup Evas_Canvas
  */
@@ -1127,6 +1028,7 @@ EAPI void evas_render_idle_flush(Evas_Canvas *obj);
  *
  * @note Currently EFL only creates a seat, mouse and keyboard.
  *
+ * @param[in] obj The object.
  * @param[in] type The class of the default device to fetch.
  *
  * @return The default device or @c null on error.
@@ -1145,6 +1047,7 @@ EAPI Efl_Input_Device *evas_default_device_get(const Evas_Canvas *obj, Efl_Input
  * location, returning it as the function return value. If @c e is invalid, the
  * results are undefined.
  *
+ * @param[in] obj The object.
  * @param[in] y The canvas y coordinate.
  *
  * @return The output/screen coordinate translated to output coordinates.
